# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

SNAKE_TO_CAMEL_CASE_TABLE = {
    "acceleration_status": "accelerationStatus",
    "accelerator_arn": "acceleratorArn",
    "accept_status": "acceptStatus",
    "acceptance_required": "acceptanceRequired",
    "access_group_id": "accessGroupId",
    "access_key": "accessKey",
    "access_log_settings": "accessLogSettings",
    "access_logs": "accessLogs",
    "access_policies": "accessPolicies",
    "access_policy": "accessPolicy",
    "access_url": "accessUrl",
    "account_aggregation_source": "accountAggregationSource",
    "account_alias": "accountAlias",
    "account_id": "accountId",
    "actions_enabled": "actionsEnabled",
    "activated_rules": "activatedRules",
    "activation_code": "activationCode",
    "activation_key": "activationKey",
    "active_directory_id": "activeDirectoryId",
    "add_header_actions": "addHeaderActions",
    "additional_artifacts": "additionalArtifacts",
    "additional_authentication_providers": "additionalAuthenticationProviders",
    "additional_info": "additionalInfo",
    "additional_schema_elements": "additionalSchemaElements",
    "address_family": "addressFamily",
    "adjustment_type": "adjustmentType",
    "admin_account_id": "adminAccountId",
    "admin_create_user_config": "adminCreateUserConfig",
    "administration_role_arn": "administrationRoleArn",
    "advanced_options": "advancedOptions",
    "advanced_security_options": "advancedSecurityOptions",
    "agent_arns": "agentArns",
    "agent_version": "agentVersion",
    "alarm_actions": "alarmActions",
    "alarm_configuration": "alarmConfiguration",
    "alarm_description": "alarmDescription",
    "alb_target_group_arn": "albTargetGroupArn",
    "alias_attributes": "aliasAttributes",
    "all_settings": "allSettings",
    "allocated_memory": "allocatedMemory",
    "allocated_storage": "allocatedStorage",
    "allocation_id": "allocationId",
    "allocation_strategy": "allocationStrategy",
    "allow_external_principals": "allowExternalPrincipals",
    "allow_major_version_upgrade": "allowMajorVersionUpgrade",
    "allow_overwrite": "allowOverwrite",
    "allow_reassociation": "allowReassociation",
    "allow_self_management": "allowSelfManagement",
    "allow_ssh": "allowSsh",
    "allow_sudo": "allowSudo",
    "allow_unassociated_targets": "allowUnassociatedTargets",
    "allow_unauthenticated_identities": "allowUnauthenticatedIdentities",
    "allow_users_to_change_password": "allowUsersToChangePassword",
    "allow_version_upgrade": "allowVersionUpgrade",
    "allowed_account_ids": "allowedAccountIds",
    "allowed_oauth_flows": "allowedOauthFlows",
    "allowed_oauth_flows_user_pool_client": "allowedOauthFlowsUserPoolClient",
    "allowed_oauth_scopes": "allowedOauthScopes",
    "allowed_pattern": "allowedPattern",
    "allowed_prefixes": "allowedPrefixes",
    "allowed_principals": "allowedPrincipals",
    "amazon_address": "amazonAddress",
    "amazon_side_asn": "amazonSideAsn",
    "ami_id": "amiId",
    "ami_type": "amiType",
    "analytics_configuration": "analyticsConfiguration",
    "analyzer_name": "analyzerName",
    "api_endpoint": "apiEndpoint",
    "api_id": "apiId",
    "api_key": "apiKey",
    "api_key_required": "apiKeyRequired",
    "api_key_selection_expression": "apiKeySelectionExpression",
    "api_key_source": "apiKeySource",
    "api_mapping_key": "apiMappingKey",
    "api_mapping_selection_expression": "apiMappingSelectionExpression",
    "api_stages": "apiStages",
    "app_name": "appName",
    "app_server": "appServer",
    "app_server_version": "appServerVersion",
    "app_sources": "appSources",
    "application_failure_feedback_role_arn": "applicationFailureFeedbackRoleArn",
    "application_id": "applicationId",
    "application_success_feedback_role_arn": "applicationSuccessFeedbackRoleArn",
    "application_success_feedback_sample_rate": "applicationSuccessFeedbackSampleRate",
    "apply_immediately": "applyImmediately",
    "approval_rules": "approvalRules",
    "approved_patches": "approvedPatches",
    "approved_patches_compliance_level": "approvedPatchesComplianceLevel",
    "appversion_lifecycle": "appversionLifecycle",
    "arn_suffix": "arnSuffix",
    "artifact_store": "artifactStore",
    "assign_generated_ipv6_cidr_block": "assignGeneratedIpv6CidrBlock",
    "assign_ipv6_address_on_creation": "assignIpv6AddressOnCreation",
    "associate_public_ip_address": "associatePublicIpAddress",
    "associate_with_private_ip": "associateWithPrivateIp",
    "associated_gateway_id": "associatedGatewayId",
    "associated_gateway_owner_account_id": "associatedGatewayOwnerAccountId",
    "associated_gateway_type": "associatedGatewayType",
    "association_default_route_table_id": "associationDefaultRouteTableId",
    "association_id": "associationId",
    "association_name": "associationName",
    "assume_role": "assumeRole",
    "assume_role_policy": "assumeRolePolicy",
    "at_rest_encryption_enabled": "atRestEncryptionEnabled",
    "attachment_id": "attachmentId",
    "attachments_sources": "attachmentsSources",
    "attribute_mapping": "attributeMapping",
    "audio_codec_options": "audioCodecOptions",
    "audit_stream_arn": "auditStreamArn",
    "auth_token": "authToken",
    "auth_type": "authType",
    "authentication_configuration": "authenticationConfiguration",
    "authentication_options": "authenticationOptions",
    "authentication_type": "authenticationType",
    "authorization_scopes": "authorizationScopes",
    "authorization_type": "authorizationType",
    "authorize_all_groups": "authorizeAllGroups",
    "authorizer_credentials": "authorizerCredentials",
    "authorizer_credentials_arn": "authorizerCredentialsArn",
    "authorizer_id": "authorizerId",
    "authorizer_result_ttl_in_seconds": "authorizerResultTtlInSeconds",
    "authorizer_type": "authorizerType",
    "authorizer_uri": "authorizerUri",
    "auto_accept": "autoAccept",
    "auto_accept_shared_attachments": "autoAcceptSharedAttachments",
    "auto_assign_elastic_ips": "autoAssignElasticIps",
    "auto_assign_public_ips": "autoAssignPublicIps",
    "auto_bundle_on_deploy": "autoBundleOnDeploy",
    "auto_deploy": "autoDeploy",
    "auto_deployed": "autoDeployed",
    "auto_enable": "autoEnable",
    "auto_healing": "autoHealing",
    "auto_minor_version_upgrade": "autoMinorVersionUpgrade",
    "auto_rollback_configuration": "autoRollbackConfiguration",
    "auto_scaling_group_provider": "autoScalingGroupProvider",
    "auto_scaling_type": "autoScalingType",
    "auto_verified_attributes": "autoVerifiedAttributes",
    "automated_snapshot_retention_period": "automatedSnapshotRetentionPeriod",
    "automatic_backup_retention_days": "automaticBackupRetentionDays",
    "automatic_failover_enabled": "automaticFailoverEnabled",
    "automatic_stop_time_minutes": "automaticStopTimeMinutes",
    "automation_target_parameter_name": "automationTargetParameterName",
    "autoscaling_group_name": "autoscalingGroupName",
    "autoscaling_groups": "autoscalingGroups",
    "autoscaling_policy": "autoscalingPolicy",
    "autoscaling_role": "autoscalingRole",
    "availability_zone": "availabilityZone",
    "availability_zone_id": "availabilityZoneId",
    "availability_zone_name": "availabilityZoneName",
    "availability_zones": "availabilityZones",
    "aws_account_id": "awsAccountId",
    "aws_device": "awsDevice",
    "aws_flow_ruby_settings": "awsFlowRubySettings",
    "aws_kms_key_arn": "awsKmsKeyArn",
    "aws_service_access_principals": "awsServiceAccessPrincipals",
    "aws_service_name": "awsServiceName",
    "az_mode": "azMode",
    "backtrack_window": "backtrackWindow",
    "backup_retention_period": "backupRetentionPeriod",
    "backup_window": "backupWindow",
    "badge_enabled": "badgeEnabled",
    "badge_url": "badgeUrl",
    "base_endpoint_dns_names": "baseEndpointDnsNames",
    "base_path": "basePath",
    "baseline_id": "baselineId",
    "batch_size": "batchSize",
    "batch_target": "batchTarget",
    "behavior_on_mx_failure": "behaviorOnMxFailure",
    "berkshelf_version": "berkshelfVersion",
    "bgp_asn": "bgpAsn",
    "bgp_auth_key": "bgpAuthKey",
    "bgp_peer_id": "bgpPeerId",
    "bgp_status": "bgpStatus",
    "bid_price": "bidPrice",
    "billing_mode": "billingMode",
    "binary_media_types": "binaryMediaTypes",
    "bisect_batch_on_function_error": "bisectBatchOnFunctionError",
    "block_device_mappings": "blockDeviceMappings",
    "block_duration_minutes": "blockDurationMinutes",
    "block_public_acls": "blockPublicAcls",
    "block_public_policy": "blockPublicPolicy",
    "blue_green_deployment_config": "blueGreenDeploymentConfig",
    "blueprint_id": "blueprintId",
    "bootstrap_actions": "bootstrapActions",
    "bootstrap_brokers": "bootstrapBrokers",
    "bootstrap_brokers_tls": "bootstrapBrokersTls",
    "bounce_actions": "bounceActions",
    "branch_filter": "branchFilter",
    "broker_name": "brokerName",
    "broker_node_group_info": "brokerNodeGroupInfo",
    "bucket_domain_name": "bucketDomainName",
    "bucket_name": "bucketName",
    "bucket_prefix": "bucketPrefix",
    "bucket_regional_domain_name": "bucketRegionalDomainName",
    "budget_type": "budgetType",
    "build_id": "buildId",
    "build_timeout": "buildTimeout",
    "bundle_id": "bundleId",
    "bundler_version": "bundlerVersion",
    "byte_match_tuples": "byteMatchTuples",
    "ca_cert_identifier": "caCertIdentifier",
    "cache_cluster_enabled": "cacheClusterEnabled",
    "cache_cluster_size": "cacheClusterSize",
    "cache_control": "cacheControl",
    "cache_key_parameters": "cacheKeyParameters",
    "cache_namespace": "cacheNamespace",
    "cache_nodes": "cacheNodes",
    "caching_config": "cachingConfig",
    "callback_urls": "callbackUrls",
    "caller_reference": "callerReference",
    "campaign_hook": "campaignHook",
    "capacity_provider_strategies": "capacityProviderStrategies",
    "capacity_providers": "capacityProviders",
    "capacity_reservation_specification": "capacityReservationSpecification",
    "catalog_id": "catalogId",
    "catalog_targets": "catalogTargets",
    "cdc_start_time": "cdcStartTime",
    "certificate_arn": "certificateArn",
    "certificate_authority": "certificateAuthority",
    "certificate_authority_arn": "certificateAuthorityArn",
    "certificate_authority_configuration": "certificateAuthorityConfiguration",
    "certificate_body": "certificateBody",
    "certificate_chain": "certificateChain",
    "certificate_id": "certificateId",
    "certificate_name": "certificateName",
    "certificate_pem": "certificatePem",
    "certificate_private_key": "certificatePrivateKey",
    "certificate_signing_request": "certificateSigningRequest",
    "certificate_upload_date": "certificateUploadDate",
    "certificate_wallet": "certificateWallet",
    "channel_id": "channelId",
    "chap_enabled": "chapEnabled",
    "character_set_name": "characterSetName",
    "child_health_threshold": "childHealthThreshold",
    "child_healthchecks": "childHealthchecks",
    "cidr_block": "cidrBlock",
    "cidr_blocks": "cidrBlocks",
    "ciphertext_blob": "ciphertextBlob",
    "classification_type": "classificationType",
    "client_affinity": "clientAffinity",
    "client_authentication": "clientAuthentication",
    "client_certificate_id": "clientCertificateId",
    "client_cidr_block": "clientCidrBlock",
    "client_id": "clientId",
    "client_id_lists": "clientIdLists",
    "client_lists": "clientLists",
    "client_secret": "clientSecret",
    "client_token": "clientToken",
    "client_vpn_endpoint_id": "clientVpnEndpointId",
    "clone_url_http": "cloneUrlHttp",
    "clone_url_ssh": "cloneUrlSsh",
    "cloud_watch_logs_group_arn": "cloudWatchLogsGroupArn",
    "cloud_watch_logs_role_arn": "cloudWatchLogsRoleArn",
    "cloudfront_access_identity_path": "cloudfrontAccessIdentityPath",
    "cloudfront_distribution_arn": "cloudfrontDistributionArn",
    "cloudfront_domain_name": "cloudfrontDomainName",
    "cloudfront_zone_id": "cloudfrontZoneId",
    "cloudwatch_alarm": "cloudwatchAlarm",
    "cloudwatch_alarm_name": "cloudwatchAlarmName",
    "cloudwatch_alarm_region": "cloudwatchAlarmRegion",
    "cloudwatch_destinations": "cloudwatchDestinations",
    "cloudwatch_log_group_arn": "cloudwatchLogGroupArn",
    "cloudwatch_logging_options": "cloudwatchLoggingOptions",
    "cloudwatch_metric": "cloudwatchMetric",
    "cloudwatch_role_arn": "cloudwatchRoleArn",
    "cluster_address": "clusterAddress",
    "cluster_certificates": "clusterCertificates",
    "cluster_config": "clusterConfig",
    "cluster_endpoint_identifier": "clusterEndpointIdentifier",
    "cluster_id": "clusterId",
    "cluster_identifier": "clusterIdentifier",
    "cluster_identifier_prefix": "clusterIdentifierPrefix",
    "cluster_members": "clusterMembers",
    "cluster_mode": "clusterMode",
    "cluster_name": "clusterName",
    "cluster_parameter_group_name": "clusterParameterGroupName",
    "cluster_public_key": "clusterPublicKey",
    "cluster_resource_id": "clusterResourceId",
    "cluster_revision_number": "clusterRevisionNumber",
    "cluster_security_groups": "clusterSecurityGroups",
    "cluster_state": "clusterState",
    "cluster_subnet_group_name": "clusterSubnetGroupName",
    "cluster_type": "clusterType",
    "cluster_version": "clusterVersion",
    "cname_prefix": "cnamePrefix",
    "cognito_identity_providers": "cognitoIdentityProviders",
    "cognito_options": "cognitoOptions",
    "company_code": "companyCode",
    "comparison_operator": "comparisonOperator",
    "compatible_runtimes": "compatibleRuntimes",
    "complete_lock": "completeLock",
    "compliance_severity": "complianceSeverity",
    "compute_environment_name": "computeEnvironmentName",
    "compute_environment_name_prefix": "computeEnvironmentNamePrefix",
    "compute_environments": "computeEnvironments",
    "compute_platform": "computePlatform",
    "compute_resources": "computeResources",
    "computer_name": "computerName",
    "configuration_endpoint": "configurationEndpoint",
    "configuration_endpoint_address": "configurationEndpointAddress",
    "configuration_id": "configurationId",
    "configuration_info": "configurationInfo",
    "configuration_manager_name": "configurationManagerName",
    "configuration_manager_version": "configurationManagerVersion",
    "configuration_set_name": "configurationSetName",
    "configurations_json": "configurationsJson",
    "confirmation_timeout_in_minutes": "confirmationTimeoutInMinutes",
    "connect_settings": "connectSettings",
    "connection_draining": "connectionDraining",
    "connection_draining_timeout": "connectionDrainingTimeout",
    "connection_events": "connectionEvents",
    "connection_id": "connectionId",
    "connection_log_options": "connectionLogOptions",
    "connection_notification_arn": "connectionNotificationArn",
    "connection_properties": "connectionProperties",
    "connection_type": "connectionType",
    "connections_bandwidth": "connectionsBandwidth",
    "container_definitions": "containerDefinitions",
    "container_name": "containerName",
    "container_properties": "containerProperties",
    "content_base64": "contentBase64",
    "content_based_deduplication": "contentBasedDeduplication",
    "content_config": "contentConfig",
    "content_config_permissions": "contentConfigPermissions",
    "content_disposition": "contentDisposition",
    "content_encoding": "contentEncoding",
    "content_handling": "contentHandling",
    "content_handling_strategy": "contentHandlingStrategy",
    "content_language": "contentLanguage",
    "content_type": "contentType",
    "cookie_expiration_period": "cookieExpirationPeriod",
    "cookie_name": "cookieName",
    "copy_tags_to_backups": "copyTagsToBackups",
    "copy_tags_to_snapshot": "copyTagsToSnapshot",
    "core_instance_group": "coreInstanceGroup",
    "cors_configuration": "corsConfiguration",
    "cors_rules": "corsRules",
    "cost_filters": "costFilters",
    "cost_types": "costTypes",
    "cpu_core_count": "cpuCoreCount",
    "cpu_count": "cpuCount",
    "cpu_options": "cpuOptions",
    "cpu_threads_per_core": "cpuThreadsPerCore",
    "create_date": "createDate",
    "create_timestamp": "createTimestamp",
    "created_at": "createdAt",
    "created_date": "createdDate",
    "created_time": "createdTime",
    "creation_date": "creationDate",
    "creation_time": "creationTime",
    "creation_token": "creationToken",
    "credential_duration": "credentialDuration",
    "credentials_arn": "credentialsArn",
    "credit_specification": "creditSpecification",
    "cross_zone_load_balancing": "crossZoneLoadBalancing",
    "csv_classifier": "csvClassifier",
    "current_version": "currentVersion",
    "custom_ami_id": "customAmiId",
    "custom_configure_recipes": "customConfigureRecipes",
    "custom_cookbooks_sources": "customCookbooksSources",
    "custom_deploy_recipes": "customDeployRecipes",
    "custom_endpoint_type": "customEndpointType",
    "custom_error_responses": "customErrorResponses",
    "custom_instance_profile_arn": "customInstanceProfileArn",
    "custom_json": "customJson",
    "custom_security_group_ids": "customSecurityGroupIds",
    "custom_setup_recipes": "customSetupRecipes",
    "custom_shutdown_recipes": "customShutdownRecipes",
    "custom_suffix": "customSuffix",
    "custom_undeploy_recipes": "customUndeployRecipes",
    "customer_address": "customerAddress",
    "customer_aws_id": "customerAwsId",
    "customer_gateway_configuration": "customerGatewayConfiguration",
    "customer_gateway_id": "customerGatewayId",
    "customer_master_key_spec": "customerMasterKeySpec",
    "customer_owned_ip": "customerOwnedIp",
    "customer_owned_ipv4_pool": "customerOwnedIpv4Pool",
    "customer_user_name": "customerUserName",
    "daily_automatic_backup_start_time": "dailyAutomaticBackupStartTime",
    "dashboard_arn": "dashboardArn",
    "dashboard_body": "dashboardBody",
    "dashboard_name": "dashboardName",
    "data_encryption_key_id": "dataEncryptionKeyId",
    "data_retention_in_hours": "dataRetentionInHours",
    "data_source": "dataSource",
    "data_source_arn": "dataSourceArn",
    "data_source_database_name": "dataSourceDatabaseName",
    "data_source_type": "dataSourceType",
    "data_type": "dataType",
    "database_name": "databaseName",
    "datapoints_to_alarm": "datapointsToAlarm",
    "db_cluster_identifier": "dbClusterIdentifier",
    "db_cluster_parameter_group_name": "dbClusterParameterGroupName",
    "db_cluster_snapshot_arn": "dbClusterSnapshotArn",
    "db_cluster_snapshot_identifier": "dbClusterSnapshotIdentifier",
    "db_instance_identifier": "dbInstanceIdentifier",
    "db_parameter_group_name": "dbParameterGroupName",
    "db_password": "dbPassword",
    "db_snapshot_arn": "dbSnapshotArn",
    "db_snapshot_identifier": "dbSnapshotIdentifier",
    "db_subnet_group_name": "dbSubnetGroupName",
    "db_user": "dbUser",
    "dbi_resource_id": "dbiResourceId",
    "dead_letter_config": "deadLetterConfig",
    "default_action": "defaultAction",
    "default_actions": "defaultActions",
    "default_arguments": "defaultArguments",
    "default_association_route_table": "defaultAssociationRouteTable",
    "default_authentication_method": "defaultAuthenticationMethod",
    "default_availability_zone": "defaultAvailabilityZone",
    "default_branch": "defaultBranch",
    "default_cache_behavior": "defaultCacheBehavior",
    "default_capacity_provider_strategies": "defaultCapacityProviderStrategies",
    "default_client_id": "defaultClientId",
    "default_cooldown": "defaultCooldown",
    "default_instance_profile_arn": "defaultInstanceProfileArn",
    "default_network_acl_id": "defaultNetworkAclId",
    "default_os": "defaultOs",
    "default_propagation_route_table": "defaultPropagationRouteTable",
    "default_redirect_uri": "defaultRedirectUri",
    "default_result": "defaultResult",
    "default_root_device_type": "defaultRootDeviceType",
    "default_root_object": "defaultRootObject",
    "default_route_settings": "defaultRouteSettings",
    "default_route_table_association": "defaultRouteTableAssociation",
    "default_route_table_id": "defaultRouteTableId",
    "default_route_table_propagation": "defaultRouteTablePropagation",
    "default_run_properties": "defaultRunProperties",
    "default_security_group_id": "defaultSecurityGroupId",
    "default_sender_id": "defaultSenderId",
    "default_sms_type": "defaultSmsType",
    "default_ssh_key_name": "defaultSshKeyName",
    "default_storage_class": "defaultStorageClass",
    "default_subnet_id": "defaultSubnetId",
    "default_value": "defaultValue",
    "default_version": "defaultVersion",
    "default_version_id": "defaultVersionId",
    "delay_seconds": "delaySeconds",
    "delegation_set_id": "delegationSetId",
    "delete_automated_backups": "deleteAutomatedBackups",
    "delete_ebs": "deleteEbs",
    "delete_eip": "deleteEip",
    "deletion_protection": "deletionProtection",
    "deletion_window_in_days": "deletionWindowInDays",
    "delivery_policy": "deliveryPolicy",
    "delivery_status_iam_role_arn": "deliveryStatusIamRoleArn",
    "delivery_status_success_sampling_rate": "deliveryStatusSuccessSamplingRate",
    "deployment_config_id": "deploymentConfigId",
    "deployment_config_name": "deploymentConfigName",
    "deployment_controller": "deploymentController",
    "deployment_group_name": "deploymentGroupName",
    "deployment_id": "deploymentId",
    "deployment_maximum_percent": "deploymentMaximumPercent",
    "deployment_minimum_healthy_percent": "deploymentMinimumHealthyPercent",
    "deployment_mode": "deploymentMode",
    "deployment_style": "deploymentStyle",
    "deployment_type": "deploymentType",
    "deregistration_delay": "deregistrationDelay",
    "desired_capacity": "desiredCapacity",
    "desired_count": "desiredCount",
    "destination_arn": "destinationArn",
    "destination_cidr_block": "destinationCidrBlock",
    "destination_config": "destinationConfig",
    "destination_id": "destinationId",
    "destination_ipv6_cidr_block": "destinationIpv6CidrBlock",
    "destination_location_arn": "destinationLocationArn",
    "destination_name": "destinationName",
    "destination_port_range": "destinationPortRange",
    "destination_prefix_list_id": "destinationPrefixListId",
    "destination_stream_arn": "destinationStreamArn",
    "detail_type": "detailType",
    "detector_id": "detectorId",
    "developer_provider_name": "developerProviderName",
    "device_ca_certificate": "deviceCaCertificate",
    "device_configuration": "deviceConfiguration",
    "device_index": "deviceIndex",
    "device_name": "deviceName",
    "dhcp_options_id": "dhcpOptionsId",
    "direct_internet_access": "directInternetAccess",
    "directory_id": "directoryId",
    "directory_name": "directoryName",
    "directory_type": "directoryType",
    "disable_api_termination": "disableApiTermination",
    "disable_email_notification": "disableEmailNotification",
    "disable_rollback": "disableRollback",
    "disk_id": "diskId",
    "disk_size": "diskSize",
    "display_name": "displayName",
    "dkim_tokens": "dkimTokens",
    "dns_config": "dnsConfig",
    "dns_entries": "dnsEntries",
    "dns_ip_addresses": "dnsIpAddresses",
    "dns_ips": "dnsIps",
    "dns_name": "dnsName",
    "dns_servers": "dnsServers",
    "dns_support": "dnsSupport",
    "document_format": "documentFormat",
    "document_root": "documentRoot",
    "document_type": "documentType",
    "document_version": "documentVersion",
    "documentation_version": "documentationVersion",
    "domain_endpoint_options": "domainEndpointOptions",
    "domain_iam_role_name": "domainIamRoleName",
    "domain_id": "domainId",
    "domain_name": "domainName",
    "domain_name_configuration": "domainNameConfiguration",
    "domain_name_servers": "domainNameServers",
    "domain_validation_options": "domainValidationOptions",
    "drain_elb_on_shutdown": "drainElbOnShutdown",
    "drop_invalid_header_fields": "dropInvalidHeaderFields",
    "duration_seconds": "durationSeconds",
    "dx_gateway_association_id": "dxGatewayAssociationId",
    "dx_gateway_id": "dxGatewayId",
    "dx_gateway_owner_account_id": "dxGatewayOwnerAccountId",
    "dynamodb_config": "dynamodbConfig",
    "dynamodb_targets": "dynamodbTargets",
    "ebs_block_devices": "ebsBlockDevices",
    "ebs_configs": "ebsConfigs",
    "ebs_optimized": "ebsOptimized",
    "ebs_options": "ebsOptions",
    "ebs_root_volume_size": "ebsRootVolumeSize",
    "ebs_volumes": "ebsVolumes",
    "ec2_attributes": "ec2Attributes",
    "ec2_config": "ec2Config",
    "ec2_inbound_permissions": "ec2InboundPermissions",
    "ec2_instance_id": "ec2InstanceId",
    "ec2_instance_type": "ec2InstanceType",
    "ec2_tag_filters": "ec2TagFilters",
    "ec2_tag_sets": "ec2TagSets",
    "ecs_cluster_arn": "ecsClusterArn",
    "ecs_service": "ecsService",
    "ecs_target": "ecsTarget",
    "efs_file_system_arn": "efsFileSystemArn",
    "egress_only_gateway_id": "egressOnlyGatewayId",
    "elastic_gpu_specifications": "elasticGpuSpecifications",
    "elastic_inference_accelerator": "elasticInferenceAccelerator",
    "elastic_ip": "elasticIp",
    "elastic_load_balancer": "elasticLoadBalancer",
    "elasticsearch_config": "elasticsearchConfig",
    "elasticsearch_configuration": "elasticsearchConfiguration",
    "elasticsearch_settings": "elasticsearchSettings",
    "elasticsearch_version": "elasticsearchVersion",
    "email_configuration": "emailConfiguration",
    "email_verification_message": "emailVerificationMessage",
    "email_verification_subject": "emailVerificationSubject",
    "ena_support": "enaSupport",
    "enable_classiclink": "enableClassiclink",
    "enable_classiclink_dns_support": "enableClassiclinkDnsSupport",
    "enable_cloudwatch_logs_exports": "enableCloudwatchLogsExports",
    "enable_cross_zone_load_balancing": "enableCrossZoneLoadBalancing",
    "enable_deletion_protection": "enableDeletionProtection",
    "enable_dns_hostnames": "enableDnsHostnames",
    "enable_dns_support": "enableDnsSupport",
    "enable_ecs_managed_tags": "enableEcsManagedTags",
    "enable_http2": "enableHttp2",
    "enable_http_endpoint": "enableHttpEndpoint",
    "enable_key_rotation": "enableKeyRotation",
    "enable_log_file_validation": "enableLogFileValidation",
    "enable_logging": "enableLogging",
    "enable_monitoring": "enableMonitoring",
    "enable_network_isolation": "enableNetworkIsolation",
    "enable_sni": "enableSni",
    "enable_ssl": "enableSsl",
    "enable_sso": "enableSso",
    "enabled_cloudwatch_logs_exports": "enabledCloudwatchLogsExports",
    "enabled_cluster_log_types": "enabledClusterLogTypes",
    "enabled_metrics": "enabledMetrics",
    "enabled_policy_types": "enabledPolicyTypes",
    "encoded_key": "encodedKey",
    "encrypt_at_rest": "encryptAtRest",
    "encrypted_fingerprint": "encryptedFingerprint",
    "encrypted_password": "encryptedPassword",
    "encrypted_private_key": "encryptedPrivateKey",
    "encrypted_secret": "encryptedSecret",
    "encryption_config": "encryptionConfig",
    "encryption_configuration": "encryptionConfiguration",
    "encryption_configurations": "encryptionConfigurations",
    "encryption_info": "encryptionInfo",
    "encryption_key": "encryptionKey",
    "encryption_options": "encryptionOptions",
    "encryption_type": "encryptionType",
    "end_date": "endDate",
    "end_date_type": "endDateType",
    "end_time": "endTime",
    "endpoint_arn": "endpointArn",
    "endpoint_auto_confirms": "endpointAutoConfirms",
    "endpoint_config_name": "endpointConfigName",
    "endpoint_configuration": "endpointConfiguration",
    "endpoint_configurations": "endpointConfigurations",
    "endpoint_details": "endpointDetails",
    "endpoint_group_region": "endpointGroupRegion",
    "endpoint_id": "endpointId",
    "endpoint_type": "endpointType",
    "endpoint_url": "endpointUrl",
    "enforce_consumer_deletion": "enforceConsumerDeletion",
    "engine_mode": "engineMode",
    "engine_name": "engineName",
    "engine_type": "engineType",
    "engine_version": "engineVersion",
    "enhanced_monitoring": "enhancedMonitoring",
    "enhanced_vpc_routing": "enhancedVpcRouting",
    "eni_id": "eniId",
    "environment_id": "environmentId",
    "ephemeral_block_devices": "ephemeralBlockDevices",
    "ephemeral_storage": "ephemeralStorage",
    "error_action": "errorAction",
    "estimated_instance_warmup": "estimatedInstanceWarmup",
    "evaluate_low_sample_count_percentiles": "evaluateLowSampleCountPercentiles",
    "evaluation_periods": "evaluationPeriods",
    "event_categories": "eventCategories",
    "event_delivery_failure_topic_arn": "eventDeliveryFailureTopicArn",
    "event_endpoint_created_topic_arn": "eventEndpointCreatedTopicArn",
    "event_endpoint_deleted_topic_arn": "eventEndpointDeletedTopicArn",
    "event_endpoint_updated_topic_arn": "eventEndpointUpdatedTopicArn",
    "event_pattern": "eventPattern",
    "event_selectors": "eventSelectors",
    "event_source_arn": "eventSourceArn",
    "event_source_token": "eventSourceToken",
    "event_type_ids": "eventTypeIds",
    "excess_capacity_termination_policy": "excessCapacityTerminationPolicy",
    "excluded_accounts": "excludedAccounts",
    "excluded_members": "excludedMembers",
    "execution_arn": "executionArn",
    "execution_property": "executionProperty",
    "execution_role_arn": "executionRoleArn",
    "execution_role_name": "executionRoleName",
    "expiration_date": "expirationDate",
    "expiration_model": "expirationModel",
    "expire_passwords": "expirePasswords",
    "explicit_auth_flows": "explicitAuthFlows",
    "export_path": "exportPath",
    "extended_s3_configuration": "extendedS3Configuration",
    "extended_statistic": "extendedStatistic",
    "external_id": "externalId",
    "extra_connection_attributes": "extraConnectionAttributes",
    "failover_routing_policies": "failoverRoutingPolicies",
    "failure_feedback_role_arn": "failureFeedbackRoleArn",
    "failure_threshold": "failureThreshold",
    "fargate_profile_name": "fargateProfileName",
    "feature_name": "featureName",
    "feature_set": "featureSet",
    "fifo_queue": "fifoQueue",
    "file_system_arn": "fileSystemArn",
    "file_system_config": "fileSystemConfig",
    "file_system_id": "fileSystemId",
    "fileshare_id": "fileshareId",
    "filter_groups": "filterGroups",
    "filter_pattern": "filterPattern",
    "filter_policy": "filterPolicy",
    "final_snapshot_identifier": "finalSnapshotIdentifier",
    "finding_publishing_frequency": "findingPublishingFrequency",
    "fixed_rate": "fixedRate",
    "fleet_arn": "fleetArn",
    "fleet_type": "fleetType",
    "forbidden_account_ids": "forbiddenAccountIds",
    "force_delete": "forceDelete",
    "force_destroy": "forceDestroy",
    "force_detach": "forceDetach",
    "force_detach_policies": "forceDetachPolicies",
    "force_new_deployment": "forceNewDeployment",
    "force_update_version": "forceUpdateVersion",
    "from_address": "fromAddress",
    "from_port": "fromPort",
    "function_arn": "functionArn",
    "function_id": "functionId",
    "function_name": "functionName",
    "function_version": "functionVersion",
    "gateway_arn": "gatewayArn",
    "gateway_id": "gatewayId",
    "gateway_ip_address": "gatewayIpAddress",
    "gateway_name": "gatewayName",
    "gateway_timezone": "gatewayTimezone",
    "gateway_type": "gatewayType",
    "gateway_vpc_endpoint": "gatewayVpcEndpoint",
    "generate_secret": "generateSecret",
    "geo_match_constraints": "geoMatchConstraints",
    "geolocation_routing_policies": "geolocationRoutingPolicies",
    "get_password_data": "getPasswordData",
    "global_cluster_identifier": "globalClusterIdentifier",
    "global_cluster_members": "globalClusterMembers",
    "global_cluster_resource_id": "globalClusterResourceId",
    "global_filters": "globalFilters",
    "global_secondary_indexes": "globalSecondaryIndexes",
    "glue_version": "glueVersion",
    "grant_creation_tokens": "grantCreationTokens",
    "grant_id": "grantId",
    "grant_token": "grantToken",
    "grantee_principal": "granteePrincipal",
    "grok_classifier": "grokClassifier",
    "group_name": "groupName",
    "group_names": "groupNames",
    "guess_mime_type_enabled": "guessMimeTypeEnabled",
    "hard_expiry": "hardExpiry",
    "has_logical_redundancy": "hasLogicalRedundancy",
    "has_public_access_policy": "hasPublicAccessPolicy",
    "hash_key": "hashKey",
    "hash_type": "hashType",
    "health_check": "healthCheck",
    "health_check_config": "healthCheckConfig",
    "health_check_custom_config": "healthCheckCustomConfig",
    "health_check_grace_period": "healthCheckGracePeriod",
    "health_check_grace_period_seconds": "healthCheckGracePeriodSeconds",
    "health_check_id": "healthCheckId",
    "health_check_interval_seconds": "healthCheckIntervalSeconds",
    "health_check_path": "healthCheckPath",
    "health_check_port": "healthCheckPort",
    "health_check_protocol": "healthCheckProtocol",
    "health_check_type": "healthCheckType",
    "healthcheck_method": "healthcheckMethod",
    "healthcheck_url": "healthcheckUrl",
    "heartbeat_timeout": "heartbeatTimeout",
    "hibernation_options": "hibernationOptions",
    "hls_ingests": "hlsIngests",
    "home_directory": "homeDirectory",
    "home_region": "homeRegion",
    "host_id": "hostId",
    "host_instance_type": "hostInstanceType",
    "host_key": "hostKey",
    "host_key_fingerprint": "hostKeyFingerprint",
    "host_vpc_id": "hostVpcId",
    "hosted_zone": "hostedZone",
    "hosted_zone_id": "hostedZoneId",
    "hostname_theme": "hostnameTheme",
    "hsm_eni_id": "hsmEniId",
    "hsm_id": "hsmId",
    "hsm_state": "hsmState",
    "hsm_type": "hsmType",
    "http_config": "httpConfig",
    "http_failure_feedback_role_arn": "httpFailureFeedbackRoleArn",
    "http_method": "httpMethod",
    "http_success_feedback_role_arn": "httpSuccessFeedbackRoleArn",
    "http_success_feedback_sample_rate": "httpSuccessFeedbackSampleRate",
    "http_version": "httpVersion",
    "iam_arn": "iamArn",
    "iam_database_authentication_enabled": "iamDatabaseAuthenticationEnabled",
    "iam_fleet_role": "iamFleetRole",
    "iam_instance_profile": "iamInstanceProfile",
    "iam_role": "iamRole",
    "iam_role_arn": "iamRoleArn",
    "iam_role_id": "iamRoleId",
    "iam_roles": "iamRoles",
    "iam_user_access_to_billing": "iamUserAccessToBilling",
    "icmp_code": "icmpCode",
    "icmp_type": "icmpType",
    "identifier_prefix": "identifierPrefix",
    "identity_pool_id": "identityPoolId",
    "identity_pool_name": "identityPoolName",
    "identity_provider": "identityProvider",
    "identity_provider_type": "identityProviderType",
    "identity_source": "identitySource",
    "identity_sources": "identitySources",
    "identity_type": "identityType",
    "identity_validation_expression": "identityValidationExpression",
    "idle_timeout": "idleTimeout",
    "idp_identifiers": "idpIdentifiers",
    "ignore_deletion_error": "ignoreDeletionError",
    "ignore_public_acls": "ignorePublicAcls",
    "ignore_tags": "ignoreTags",
    "image_id": "imageId",
    "image_location": "imageLocation",
    "image_scanning_configuration": "imageScanningConfiguration",
    "image_tag_mutability": "imageTagMutability",
    "import_path": "importPath",
    "imported_file_chunk_size": "importedFileChunkSize",
    "in_progress_validation_batches": "inProgressValidationBatches",
    "include_global_service_events": "includeGlobalServiceEvents",
    "include_original_headers": "includeOriginalHeaders",
    "included_object_versions": "includedObjectVersions",
    "inference_accelerators": "inferenceAccelerators",
    "infrastructure_class": "infrastructureClass",
    "initial_lifecycle_hooks": "initialLifecycleHooks",
    "input_bucket": "inputBucket",
    "input_parameters": "inputParameters",
    "input_path": "inputPath",
    "input_transformer": "inputTransformer",
    "install_updates_on_boot": "installUpdatesOnBoot",
    "instance_class": "instanceClass",
    "instance_count": "instanceCount",
    "instance_id": "instanceId",
    "instance_initiated_shutdown_behavior": "instanceInitiatedShutdownBehavior",
    "instance_interruption_behaviour": "instanceInterruptionBehaviour",
    "instance_market_options": "instanceMarketOptions",
    "instance_match_criteria": "instanceMatchCriteria",
    "instance_name": "instanceName",
    "instance_owner_id": "instanceOwnerId",
    "instance_platform": "instancePlatform",
    "instance_pools_to_use_count": "instancePoolsToUseCount",
    "instance_port": "instancePort",
    "instance_ports": "instancePorts",
    "instance_profile_arn": "instanceProfileArn",
    "instance_role_arn": "instanceRoleArn",
    "instance_shutdown_timeout": "instanceShutdownTimeout",
    "instance_state": "instanceState",
    "instance_tenancy": "instanceTenancy",
    "instance_type": "instanceType",
    "instance_types": "instanceTypes",
    "insufficient_data_actions": "insufficientDataActions",
    "insufficient_data_health_status": "insufficientDataHealthStatus",
    "integration_http_method": "integrationHttpMethod",
    "integration_id": "integrationId",
    "integration_method": "integrationMethod",
    "integration_response_key": "integrationResponseKey",
    "integration_response_selection_expression": "integrationResponseSelectionExpression",
    "integration_type": "integrationType",
    "integration_uri": "integrationUri",
    "invalid_user_lists": "invalidUserLists",
    "invert_healthcheck": "invertHealthcheck",
    "invitation_arn": "invitationArn",
    "invitation_message": "invitationMessage",
    "invocation_role": "invocationRole",
    "invoke_arn": "invokeArn",
    "invoke_url": "invokeUrl",
    "iot_analytics": "iotAnalytics",
    "iot_events": "iotEvents",
    "ip_address": "ipAddress",
    "ip_address_type": "ipAddressType",
    "ip_address_version": "ipAddressVersion",
    "ip_addresses": "ipAddresses",
    "ip_group_ids": "ipGroupIds",
    "ip_set_descriptors": "ipSetDescriptors",
    "ip_sets": "ipSets",
    "ipc_mode": "ipcMode",
    "ipv6_address": "ipv6Address",
    "ipv6_address_count": "ipv6AddressCount",
    "ipv6_addresses": "ipv6Addresses",
    "ipv6_association_id": "ipv6AssociationId",
    "ipv6_cidr_block": "ipv6CidrBlock",
    "ipv6_cidr_block_association_id": "ipv6CidrBlockAssociationId",
    "ipv6_cidr_blocks": "ipv6CidrBlocks",
    "ipv6_support": "ipv6Support",
    "is_enabled": "isEnabled",
    "is_ipv6_enabled": "isIpv6Enabled",
    "is_multi_region_trail": "isMultiRegionTrail",
    "is_organization_trail": "isOrganizationTrail",
    "is_static_ip": "isStaticIp",
    "jdbc_targets": "jdbcTargets",
    "joined_method": "joinedMethod",
    "joined_timestamp": "joinedTimestamp",
    "json_classifier": "jsonClassifier",
    "jumbo_frame_capable": "jumboFrameCapable",
    "jvm_options": "jvmOptions",
    "jvm_type": "jvmType",
    "jvm_version": "jvmVersion",
    "jwt_configuration": "jwtConfiguration",
    "kafka_settings": "kafkaSettings",
    "kafka_version": "kafkaVersion",
    "kafka_versions": "kafkaVersions",
    "keep_job_flow_alive_when_no_steps": "keepJobFlowAliveWhenNoSteps",
    "kerberos_attributes": "kerberosAttributes",
    "kernel_id": "kernelId",
    "key_arn": "keyArn",
    "key_fingerprint": "keyFingerprint",
    "key_id": "keyId",
    "key_material_base64": "keyMaterialBase64",
    "key_name": "keyName",
    "key_name_prefix": "keyNamePrefix",
    "key_pair_id": "keyPairId",
    "key_pair_name": "keyPairName",
    "key_prefixes": "keyPrefixes",
    "key_state": "keyState",
    "key_type": "keyType",
    "key_usage": "keyUsage",
    "kibana_endpoint": "kibanaEndpoint",
    "kinesis_destination": "kinesisDestination",
    "kinesis_settings": "kinesisSettings",
    "kinesis_source_configuration": "kinesisSourceConfiguration",
    "kinesis_target": "kinesisTarget",
    "kms_data_key_reuse_period_seconds": "kmsDataKeyReusePeriodSeconds",
    "kms_encrypted": "kmsEncrypted",
    "kms_key_arn": "kmsKeyArn",
    "kms_key_id": "kmsKeyId",
    "kms_master_key_id": "kmsMasterKeyId",
    "lag_id": "lagId",
    "lambda_": "lambda",
    "lambda_actions": "lambdaActions",
    "lambda_config": "lambdaConfig",
    "lambda_failure_feedback_role_arn": "lambdaFailureFeedbackRoleArn",
    "lambda_function_arn": "lambdaFunctionArn",
    "lambda_functions": "lambdaFunctions",
    "lambda_multi_value_headers_enabled": "lambdaMultiValueHeadersEnabled",
    "lambda_success_feedback_role_arn": "lambdaSuccessFeedbackRoleArn",
    "lambda_success_feedback_sample_rate": "lambdaSuccessFeedbackSampleRate",
    "last_modified": "lastModified",
    "last_modified_date": "lastModifiedDate",
    "last_modified_time": "lastModifiedTime",
    "last_processing_result": "lastProcessingResult",
    "last_service_error_id": "lastServiceErrorId",
    "last_update_timestamp": "lastUpdateTimestamp",
    "last_updated_date": "lastUpdatedDate",
    "last_updated_time": "lastUpdatedTime",
    "latency_routing_policies": "latencyRoutingPolicies",
    "latest_revision": "latestRevision",
    "latest_version": "latestVersion",
    "launch_configuration": "launchConfiguration",
    "launch_configurations": "launchConfigurations",
    "launch_group": "launchGroup",
    "launch_specifications": "launchSpecifications",
    "launch_template": "launchTemplate",
    "launch_template_config": "launchTemplateConfig",
    "launch_template_configs": "launchTemplateConfigs",
    "launch_type": "launchType",
    "layer_arn": "layerArn",
    "layer_ids": "layerIds",
    "layer_name": "layerName",
    "lb_port": "lbPort",
    "license_configuration_arn": "licenseConfigurationArn",
    "license_count": "licenseCount",
    "license_count_hard_limit": "licenseCountHardLimit",
    "license_counting_type": "licenseCountingType",
    "license_info": "licenseInfo",
    "license_model": "licenseModel",
    "license_rules": "licenseRules",
    "license_specifications": "licenseSpecifications",
    "lifecycle_config_name": "lifecycleConfigName",
    "lifecycle_policy": "lifecyclePolicy",
    "lifecycle_rules": "lifecycleRules",
    "lifecycle_transition": "lifecycleTransition",
    "limit_amount": "limitAmount",
    "limit_unit": "limitUnit",
    "listener_arn": "listenerArn",
    "load_balancer": "loadBalancer",
    "load_balancer_arn": "loadBalancerArn",
    "load_balancer_info": "loadBalancerInfo",
    "load_balancer_name": "loadBalancerName",
    "load_balancer_port": "loadBalancerPort",
    "load_balancer_type": "loadBalancerType",
    "load_balancers": "loadBalancers",
    "load_balancing_algorithm_type": "loadBalancingAlgorithmType",
    "local_gateway_id": "localGatewayId",
    "local_gateway_route_table_id": "localGatewayRouteTableId",
    "local_gateway_virtual_interface_group_id": "localGatewayVirtualInterfaceGroupId",
    "local_secondary_indexes": "localSecondaryIndexes",
    "location_arn": "locationArn",
    "location_uri": "locationUri",
    "lock_token": "lockToken",
    "log_config": "logConfig",
    "log_destination": "logDestination",
    "log_destination_configs": "logDestinationConfigs",
    "log_destination_type": "logDestinationType",
    "log_format": "logFormat",
    "log_group": "logGroup",
    "log_group_name": "logGroupName",
    "log_paths": "logPaths",
    "log_publishing_options": "logPublishingOptions",
    "log_uri": "logUri",
    "logging_config": "loggingConfig",
    "logging_configuration": "loggingConfiguration",
    "logging_info": "loggingInfo",
    "logging_role": "loggingRole",
    "logout_urls": "logoutUrls",
    "logs_config": "logsConfig",
    "lun_number": "lunNumber",
    "mac_address": "macAddress",
    "mail_from_domain": "mailFromDomain",
    "main_route_table_id": "mainRouteTableId",
    "maintenance_window": "maintenanceWindow",
    "maintenance_window_start_time": "maintenanceWindowStartTime",
    "major_engine_version": "majorEngineVersion",
    "manage_berkshelf": "manageBerkshelf",
    "manage_bundler": "manageBundler",
    "manage_ebs_snapshots": "manageEbsSnapshots",
    "manages_vpc_endpoints": "managesVpcEndpoints",
    "map_public_ip_on_launch": "mapPublicIpOnLaunch",
    "master_account_arn": "masterAccountArn",
    "master_account_email": "masterAccountEmail",
    "master_account_id": "masterAccountId",
    "master_id": "masterId",
    "master_instance_group": "masterInstanceGroup",
    "master_password": "masterPassword",
    "master_public_dns": "masterPublicDns",
    "master_username": "masterUsername",
    "match_criterias": "matchCriterias",
    "matching_types": "matchingTypes",
    "max_aggregation_interval": "maxAggregationInterval",
    "max_allocated_storage": "maxAllocatedStorage",
    "max_capacity": "maxCapacity",
    "max_concurrency": "maxConcurrency",
    "max_errors": "maxErrors",
    "max_instance_lifetime": "maxInstanceLifetime",
    "max_message_size": "maxMessageSize",
    "max_password_age": "maxPasswordAge",
    "max_retries": "maxRetries",
    "max_session_duration": "maxSessionDuration",
    "max_size": "maxSize",
    "maximum_batching_window_in_seconds": "maximumBatchingWindowInSeconds",
    "maximum_event_age_in_seconds": "maximumEventAgeInSeconds",
    "maximum_execution_frequency": "maximumExecutionFrequency",
    "maximum_record_age_in_seconds": "maximumRecordAgeInSeconds",
    "maximum_retry_attempts": "maximumRetryAttempts",
    "measure_latency": "measureLatency",
    "media_type": "mediaType",
    "medium_changer_type": "mediumChangerType",
    "member_account_id": "memberAccountId",
    "member_clusters": "memberClusters",
    "member_status": "memberStatus",
    "memory_size": "memorySize",
    "mesh_name": "meshName",
    "message_retention_seconds": "messageRetentionSeconds",
    "messages_per_second": "messagesPerSecond",
    "metadata_options": "metadataOptions",
    "method_path": "methodPath",
    "metric_aggregation_type": "metricAggregationType",
    "metric_groups": "metricGroups",
    "metric_name": "metricName",
    "metric_queries": "metricQueries",
    "metric_transformation": "metricTransformation",
    "metrics_granularity": "metricsGranularity",
    "mfa_configuration": "mfaConfiguration",
    "migration_type": "migrationType",
    "min_adjustment_magnitude": "minAdjustmentMagnitude",
    "min_capacity": "minCapacity",
    "min_elb_capacity": "minElbCapacity",
    "min_size": "minSize",
    "minimum_compression_size": "minimumCompressionSize",
    "minimum_healthy_hosts": "minimumHealthyHosts",
    "minimum_password_length": "minimumPasswordLength",
    "mixed_instances_policy": "mixedInstancesPolicy",
    "model_selection_expression": "modelSelectionExpression",
    "mongodb_settings": "mongodbSettings",
    "monitoring_interval": "monitoringInterval",
    "monitoring_role_arn": "monitoringRoleArn",
    "monthly_spend_limit": "monthlySpendLimit",
    "mount_options": "mountOptions",
    "mount_target_dns_name": "mountTargetDnsName",
    "multi_attach_enabled": "multiAttachEnabled",
    "multi_az": "multiAz",
    "multivalue_answer_routing_policy": "multivalueAnswerRoutingPolicy",
    "name_prefix": "namePrefix",
    "name_servers": "nameServers",
    "namespace_id": "namespaceId",
    "nat_gateway_id": "natGatewayId",
    "neptune_cluster_parameter_group_name": "neptuneClusterParameterGroupName",
    "neptune_parameter_group_name": "neptuneParameterGroupName",
    "neptune_subnet_group_name": "neptuneSubnetGroupName",
    "netbios_name_servers": "netbiosNameServers",
    "netbios_node_type": "netbiosNodeType",
    "network_acl_id": "networkAclId",
    "network_configuration": "networkConfiguration",
    "network_interface": "networkInterface",
    "network_interface_id": "networkInterfaceId",
    "network_interface_ids": "networkInterfaceIds",
    "network_interface_port": "networkInterfacePort",
    "network_interfaces": "networkInterfaces",
    "network_load_balancer_arn": "networkLoadBalancerArn",
    "network_load_balancer_arns": "networkLoadBalancerArns",
    "network_mode": "networkMode",
    "network_origin": "networkOrigin",
    "network_services": "networkServices",
    "new_game_session_protection_policy": "newGameSessionProtectionPolicy",
    "nfs_file_share_defaults": "nfsFileShareDefaults",
    "node_group_name": "nodeGroupName",
    "node_role_arn": "nodeRoleArn",
    "node_to_node_encryption": "nodeToNodeEncryption",
    "node_type": "nodeType",
    "nodejs_version": "nodejsVersion",
    "non_master_accounts": "nonMasterAccounts",
    "not_after": "notAfter",
    "not_before": "notBefore",
    "notification_arns": "notificationArns",
    "notification_metadata": "notificationMetadata",
    "notification_property": "notificationProperty",
    "notification_target_arn": "notificationTargetArn",
    "notification_topic_arn": "notificationTopicArn",
    "notification_type": "notificationType",
    "ntp_servers": "ntpServers",
    "num_cache_nodes": "numCacheNodes",
    "number_cache_clusters": "numberCacheClusters",
    "number_of_broker_nodes": "numberOfBrokerNodes",
    "number_of_nodes": "numberOfNodes",
    "number_of_workers": "numberOfWorkers",
    "object_acl": "objectAcl",
    "object_lock_configuration": "objectLockConfiguration",
    "object_lock_legal_hold_status": "objectLockLegalHoldStatus",
    "object_lock_mode": "objectLockMode",
    "object_lock_retain_until_date": "objectLockRetainUntilDate",
    "ok_actions": "okActions",
    "on_create": "onCreate",
    "on_demand_options": "onDemandOptions",
    "on_failure": "onFailure",
    "on_prem_config": "onPremConfig",
    "on_premises_instance_tag_filters": "onPremisesInstanceTagFilters",
    "on_start": "onStart",
    "open_monitoring": "openMonitoring",
    "openid_connect_config": "openidConnectConfig",
    "openid_connect_provider_arns": "openidConnectProviderArns",
    "operating_system": "operatingSystem",
    "operation_name": "operationName",
    "opt_in_status": "optInStatus",
    "optimize_for_end_user_location": "optimizeForEndUserLocation",
    "option_group_description": "optionGroupDescription",
    "option_group_name": "optionGroupName",
    "optional_fields": "optionalFields",
    "ordered_cache_behaviors": "orderedCacheBehaviors",
    "ordered_placement_strategies": "orderedPlacementStrategies",
    "organization_aggregation_source": "organizationAggregationSource",
    "origin_groups": "originGroups",
    "original_route_table_id": "originalRouteTableId",
    "outpost_arn": "outpostArn",
    "output_bucket": "outputBucket",
    "output_location": "outputLocation",
    "owner_account": "ownerAccount",
    "owner_account_id": "ownerAccountId",
    "owner_alias": "ownerAlias",
    "owner_arn": "ownerArn",
    "owner_id": "ownerId",
    "owner_information": "ownerInformation",
    "owning_account": "owningAccount",
    "packet_length": "packetLength",
    "parallelization_factor": "parallelizationFactor",
    "parameter_group_name": "parameterGroupName",
    "parameter_overrides": "parameterOverrides",
    "parent_id": "parentId",
    "partition_keys": "partitionKeys",
    "passenger_version": "passengerVersion",
    "passthrough_behavior": "passthroughBehavior",
    "password_data": "passwordData",
    "password_length": "passwordLength",
    "password_policy": "passwordPolicy",
    "password_reset_required": "passwordResetRequired",
    "password_reuse_prevention": "passwordReusePrevention",
    "patch_group": "patchGroup",
    "path_part": "pathPart",
    "payload_format_version": "payloadFormatVersion",
    "payload_url": "payloadUrl",
    "peer_account_id": "peerAccountId",
    "peer_owner_id": "peerOwnerId",
    "peer_region": "peerRegion",
    "peer_transit_gateway_id": "peerTransitGatewayId",
    "peer_vpc_id": "peerVpcId",
    "pem_encoded_certificate": "pemEncodedCertificate",
    "per_unit_storage_throughput": "perUnitStorageThroughput",
    "performance_insights_enabled": "performanceInsightsEnabled",
    "performance_insights_kms_key_id": "performanceInsightsKmsKeyId",
    "performance_insights_retention_period": "performanceInsightsRetentionPeriod",
    "performance_mode": "performanceMode",
    "permanent_deletion_time_in_days": "permanentDeletionTimeInDays",
    "permissions_boundary": "permissionsBoundary",
    "pgp_key": "pgpKey",
    "physical_connection_requirements": "physicalConnectionRequirements",
    "pid_mode": "pidMode",
    "pipeline_config": "pipelineConfig",
    "placement_constraints": "placementConstraints",
    "placement_group": "placementGroup",
    "placement_group_id": "placementGroupId",
    "placement_tenancy": "placementTenancy",
    "plan_id": "planId",
    "platform_arn": "platformArn",
    "platform_credential": "platformCredential",
    "platform_principal": "platformPrincipal",
    "platform_types": "platformTypes",
    "platform_version": "platformVersion",
    "player_latency_policies": "playerLatencyPolicies",
    "pod_execution_role_arn": "podExecutionRoleArn",
    "point_in_time_recovery": "pointInTimeRecovery",
    "policy_arn": "policyArn",
    "policy_arns": "policyArns",
    "policy_attributes": "policyAttributes",
    "policy_body": "policyBody",
    "policy_details": "policyDetails",
    "policy_document": "policyDocument",
    "policy_id": "policyId",
    "policy_name": "policyName",
    "policy_names": "policyNames",
    "policy_type": "policyType",
    "policy_type_name": "policyTypeName",
    "policy_url": "policyUrl",
    "poll_interval": "pollInterval",
    "port_ranges": "portRanges",
    "posix_user": "posixUser",
    "preferred_availability_zones": "preferredAvailabilityZones",
    "preferred_backup_window": "preferredBackupWindow",
    "preferred_file_server_ip": "preferredFileServerIp",
    "preferred_maintenance_window": "preferredMaintenanceWindow",
    "preferred_subnet_id": "preferredSubnetId",
    "prefix_list_id": "prefixListId",
    "prefix_list_ids": "prefixListIds",
    "prevent_user_existence_errors": "preventUserExistenceErrors",
    "price_class": "priceClass",
    "pricing_plan": "pricingPlan",
    "primary_container": "primaryContainer",
    "primary_endpoint_address": "primaryEndpointAddress",
    "primary_network_interface_id": "primaryNetworkInterfaceId",
    "principal_arn": "principalArn",
    "private_dns": "privateDns",
    "private_dns_enabled": "privateDnsEnabled",
    "private_dns_name": "privateDnsName",
    "private_ip": "privateIp",
    "private_ip_address": "privateIpAddress",
    "private_ips": "privateIps",
    "private_ips_count": "privateIpsCount",
    "private_key": "privateKey",
    "product_arn": "productArn",
    "product_code": "productCode",
    "production_variants": "productionVariants",
    "project_name": "projectName",
    "promotion_tier": "promotionTier",
    "promotional_messages_per_second": "promotionalMessagesPerSecond",
    "propagate_tags": "propagateTags",
    "propagating_vgws": "propagatingVgws",
    "propagation_default_route_table_id": "propagationDefaultRouteTableId",
    "proposal_id": "proposalId",
    "protect_from_scale_in": "protectFromScaleIn",
    "protocol_type": "protocolType",
    "provider_arns": "providerArns",
    "provider_details": "providerDetails",
    "provider_name": "providerName",
    "provider_type": "providerType",
    "provisioned_concurrent_executions": "provisionedConcurrentExecutions",
    "provisioned_throughput_in_mibps": "provisionedThroughputInMibps",
    "proxy_configuration": "proxyConfiguration",
    "proxy_protocol_v2": "proxyProtocolV2",
    "public_access_block_configuration": "publicAccessBlockConfiguration",
    "public_dns": "publicDns",
    "public_ip": "publicIp",
    "public_ip_address": "publicIpAddress",
    "public_ipv4_pool": "publicIpv4Pool",
    "public_key": "publicKey",
    "publicly_accessible": "publiclyAccessible",
    "qualified_arn": "qualifiedArn",
    "queue_url": "queueUrl",
    "queued_timeout": "queuedTimeout",
    "quiet_time": "quietTime",
    "quota_code": "quotaCode",
    "quota_name": "quotaName",
    "quota_settings": "quotaSettings",
    "rails_env": "railsEnv",
    "ram_disk_id": "ramDiskId",
    "ram_size": "ramSize",
    "ramdisk_id": "ramdiskId",
    "range_key": "rangeKey",
    "rate_key": "rateKey",
    "rate_limit": "rateLimit",
    "raw_message_delivery": "rawMessageDelivery",
    "rds_db_instance_arn": "rdsDbInstanceArn",
    "read_attributes": "readAttributes",
    "read_capacity": "readCapacity",
    "read_only": "readOnly",
    "reader_endpoint": "readerEndpoint",
    "receive_wait_time_seconds": "receiveWaitTimeSeconds",
    "receiver_account_id": "receiverAccountId",
    "recording_group": "recordingGroup",
    "recovery_points": "recoveryPoints",
    "recovery_window_in_days": "recoveryWindowInDays",
    "redacted_fields": "redactedFields",
    "redrive_policy": "redrivePolicy",
    "redshift_configuration": "redshiftConfiguration",
    "reference_data_sources": "referenceDataSources",
    "reference_name": "referenceName",
    "refresh_token_validity": "refreshTokenValidity",
    "regex_match_tuples": "regexMatchTuples",
    "regex_pattern_strings": "regexPatternStrings",
    "regional_certificate_arn": "regionalCertificateArn",
    "regional_certificate_name": "regionalCertificateName",
    "regional_domain_name": "regionalDomainName",
    "regional_zone_id": "regionalZoneId",
    "registered_by": "registeredBy",
    "registration_code": "registrationCode",
    "registration_count": "registrationCount",
    "registration_limit": "registrationLimit",
    "registry_id": "registryId",
    "regular_expressions": "regularExpressions",
    "rejected_patches": "rejectedPatches",
    "relationship_status": "relationshipStatus",
    "release_label": "releaseLabel",
    "release_version": "releaseVersion",
    "remote_access": "remoteAccess",
    "remote_administration_endpoint": "remoteAdministrationEndpoint",
    "remote_domain_name": "remoteDomainName",
    "replace_unhealthy_instances": "replaceUnhealthyInstances",
    "replicate_source_db": "replicateSourceDb",
    "replication_configuration": "replicationConfiguration",
    "replication_factor": "replicationFactor",
    "replication_group_description": "replicationGroupDescription",
    "replication_group_id": "replicationGroupId",
    "replication_instance_arn": "replicationInstanceArn",
    "replication_instance_class": "replicationInstanceClass",
    "replication_instance_id": "replicationInstanceId",
    "replication_instance_private_ips": "replicationInstancePrivateIps",
    "replication_instance_public_ips": "replicationInstancePublicIps",
    "replication_source_identifier": "replicationSourceIdentifier",
    "replication_subnet_group_arn": "replicationSubnetGroupArn",
    "replication_subnet_group_description": "replicationSubnetGroupDescription",
    "replication_subnet_group_id": "replicationSubnetGroupId",
    "replication_task_arn": "replicationTaskArn",
    "replication_task_id": "replicationTaskId",
    "replication_task_settings": "replicationTaskSettings",
    "report_name": "reportName",
    "reported_agent_version": "reportedAgentVersion",
    "reported_os_family": "reportedOsFamily",
    "reported_os_name": "reportedOsName",
    "reported_os_version": "reportedOsVersion",
    "repository_id": "repositoryId",
    "repository_name": "repositoryName",
    "repository_url": "repositoryUrl",
    "request_id": "requestId",
    "request_interval": "requestInterval",
    "request_mapping_template": "requestMappingTemplate",
    "request_models": "requestModels",
    "request_parameters": "requestParameters",
    "request_payer": "requestPayer",
    "request_status": "requestStatus",
    "request_template": "requestTemplate",
    "request_templates": "requestTemplates",
    "request_validator_id": "requestValidatorId",
    "requester_managed": "requesterManaged",
    "requester_pays": "requesterPays",
    "require_lowercase_characters": "requireLowercaseCharacters",
    "require_numbers": "requireNumbers",
    "require_symbols": "requireSymbols",
    "require_uppercase_characters": "requireUppercaseCharacters",
    "requires_compatibilities": "requiresCompatibilities",
    "reservation_plan_settings": "reservationPlanSettings",
    "reserved_concurrent_executions": "reservedConcurrentExecutions",
    "reservoir_size": "reservoirSize",
    "resolver_endpoint_id": "resolverEndpointId",
    "resolver_rule_id": "resolverRuleId",
    "resource_arn": "resourceArn",
    "resource_creation_limit_policy": "resourceCreationLimitPolicy",
    "resource_group_arn": "resourceGroupArn",
    "resource_id": "resourceId",
    "resource_id_scope": "resourceIdScope",
    "resource_path": "resourcePath",
    "resource_query": "resourceQuery",
    "resource_share_arn": "resourceShareArn",
    "resource_type": "resourceType",
    "resource_types_scopes": "resourceTypesScopes",
    "response_mapping_template": "responseMappingTemplate",
    "response_models": "responseModels",
    "response_parameters": "responseParameters",
    "response_template": "responseTemplate",
    "response_templates": "responseTemplates",
    "response_type": "responseType",
    "rest_api": "restApi",
    "rest_api_id": "restApiId",
    "restrict_public_buckets": "restrictPublicBuckets",
    "retain_on_delete": "retainOnDelete",
    "retain_stack": "retainStack",
    "retention_in_days": "retentionInDays",
    "retention_period": "retentionPeriod",
    "retire_on_delete": "retireOnDelete",
    "retiring_principal": "retiringPrincipal",
    "retry_strategy": "retryStrategy",
    "revocation_configuration": "revocationConfiguration",
    "revoke_rules_on_delete": "revokeRulesOnDelete",
    "role_arn": "roleArn",
    "role_mappings": "roleMappings",
    "role_name": "roleName",
    "root_block_device": "rootBlockDevice",
    "root_block_devices": "rootBlockDevices",
    "root_device_name": "rootDeviceName",
    "root_device_type": "rootDeviceType",
    "root_device_volume_id": "rootDeviceVolumeId",
    "root_directory": "rootDirectory",
    "root_password": "rootPassword",
    "root_password_on_all_instances": "rootPasswordOnAllInstances",
    "root_resource_id": "rootResourceId",
    "root_snapshot_id": "rootSnapshotId",
    "root_volume_encryption_enabled": "rootVolumeEncryptionEnabled",
    "rotation_enabled": "rotationEnabled",
    "rotation_lambda_arn": "rotationLambdaArn",
    "rotation_rules": "rotationRules",
    "route_filter_prefixes": "routeFilterPrefixes",
    "route_id": "routeId",
    "route_key": "routeKey",
    "route_response_key": "routeResponseKey",
    "route_response_selection_expression": "routeResponseSelectionExpression",
    "route_selection_expression": "routeSelectionExpression",
    "route_settings": "routeSettings",
    "route_table_id": "routeTableId",
    "route_table_ids": "routeTableIds",
    "routing_config": "routingConfig",
    "routing_strategy": "routingStrategy",
    "ruby_version": "rubyVersion",
    "rubygems_version": "rubygemsVersion",
    "rule_action": "ruleAction",
    "rule_id": "ruleId",
    "rule_identifier": "ruleIdentifier",
    "rule_name": "ruleName",
    "rule_number": "ruleNumber",
    "rule_set_name": "ruleSetName",
    "rule_type": "ruleType",
    "rules_package_arns": "rulesPackageArns",
    "run_command_targets": "runCommandTargets",
    "running_instance_count": "runningInstanceCount",
    "runtime_configuration": "runtimeConfiguration",
    "s3_actions": "s3Actions",
    "s3_bucket": "s3Bucket",
    "s3_bucket_arn": "s3BucketArn",
    "s3_bucket_name": "s3BucketName",
    "s3_canonical_user_id": "s3CanonicalUserId",
    "s3_config": "s3Config",
    "s3_configuration": "s3Configuration",
    "s3_destination": "s3Destination",
    "s3_force_path_style": "s3ForcePathStyle",
    "s3_import": "s3Import",
    "s3_key": "s3Key",
    "s3_key_prefix": "s3KeyPrefix",
    "s3_object_version": "s3ObjectVersion",
    "s3_prefix": "s3Prefix",
    "s3_region": "s3Region",
    "s3_settings": "s3Settings",
    "s3_targets": "s3Targets",
    "saml_metadata_document": "samlMetadataDocument",
    "saml_provider_arns": "samlProviderArns",
    "scalable_dimension": "scalableDimension",
    "scalable_target_action": "scalableTargetAction",
    "scale_down_behavior": "scaleDownBehavior",
    "scaling_adjustment": "scalingAdjustment",
    "scaling_config": "scalingConfig",
    "scaling_configuration": "scalingConfiguration",
    "scan_enabled": "scanEnabled",
    "schedule_expression": "scheduleExpression",
    "schedule_identifier": "scheduleIdentifier",
    "schedule_timezone": "scheduleTimezone",
    "scheduled_action_name": "scheduledActionName",
    "scheduling_strategy": "schedulingStrategy",
    "schema_change_policy": "schemaChangePolicy",
    "schema_version": "schemaVersion",
    "scope_identifiers": "scopeIdentifiers",
    "search_string": "searchString",
    "secondary_artifacts": "secondaryArtifacts",
    "secondary_private_ips": "secondaryPrivateIps",
    "secondary_sources": "secondarySources",
    "secret_binary": "secretBinary",
    "secret_id": "secretId",
    "secret_key": "secretKey",
    "secret_string": "secretString",
    "security_configuration": "securityConfiguration",
    "security_group_id": "securityGroupId",
    "security_group_ids": "securityGroupIds",
    "security_group_names": "securityGroupNames",
    "security_groups": "securityGroups",
    "security_policy": "securityPolicy",
    "selection_pattern": "selectionPattern",
    "selection_tags": "selectionTags",
    "self_managed_active_directory": "selfManagedActiveDirectory",
    "self_service_permissions": "selfServicePermissions",
    "sender_account_id": "senderAccountId",
    "sender_id": "senderId",
    "server_certificate_arn": "serverCertificateArn",
    "server_hostname": "serverHostname",
    "server_id": "serverId",
    "server_name": "serverName",
    "server_properties": "serverProperties",
    "server_side_encryption": "serverSideEncryption",
    "server_side_encryption_configuration": "serverSideEncryptionConfiguration",
    "server_type": "serverType",
    "service_access_role": "serviceAccessRole",
    "service_code": "serviceCode",
    "service_linked_role_arn": "serviceLinkedRoleArn",
    "service_name": "serviceName",
    "service_namespace": "serviceNamespace",
    "service_registries": "serviceRegistries",
    "service_role": "serviceRole",
    "service_role_arn": "serviceRoleArn",
    "service_type": "serviceType",
    "ses_smtp_password_v4": "sesSmtpPasswordV4",
    "session_name": "sessionName",
    "session_number": "sessionNumber",
    "set_identifier": "setIdentifier",
    "shard_count": "shardCount",
    "shard_level_metrics": "shardLevelMetrics",
    "share_arn": "shareArn",
    "share_id": "shareId",
    "share_name": "shareName",
    "share_status": "shareStatus",
    "shared_credentials_file": "sharedCredentialsFile",
    "short_code": "shortCode",
    "short_name": "shortName",
    "size_constraints": "sizeConstraints",
    "skip_credentials_validation": "skipCredentialsValidation",
    "skip_destroy": "skipDestroy",
    "skip_final_backup": "skipFinalBackup",
    "skip_final_snapshot": "skipFinalSnapshot",
    "skip_get_ec2_platforms": "skipGetEc2Platforms",
    "skip_metadata_api_check": "skipMetadataApiCheck",
    "skip_region_validation": "skipRegionValidation",
    "skip_requesting_account_id": "skipRequestingAccountId",
    "slow_start": "slowStart",
    "smb_active_directory_settings": "smbActiveDirectorySettings",
    "smb_guest_password": "smbGuestPassword",
    "sms_authentication_message": "smsAuthenticationMessage",
    "sms_configuration": "smsConfiguration",
    "sms_verification_message": "smsVerificationMessage",
    "snapshot_arns": "snapshotArns",
    "snapshot_cluster_identifier": "snapshotClusterIdentifier",
    "snapshot_copy": "snapshotCopy",
    "snapshot_copy_grant_name": "snapshotCopyGrantName",
    "snapshot_delivery_properties": "snapshotDeliveryProperties",
    "snapshot_id": "snapshotId",
    "snapshot_identifier": "snapshotIdentifier",
    "snapshot_name": "snapshotName",
    "snapshot_options": "snapshotOptions",
    "snapshot_retention_limit": "snapshotRetentionLimit",
    "snapshot_type": "snapshotType",
    "snapshot_window": "snapshotWindow",
    "snapshot_without_reboot": "snapshotWithoutReboot",
    "sns_actions": "snsActions",
    "sns_destination": "snsDestination",
    "sns_topic": "snsTopic",
    "sns_topic_arn": "snsTopicArn",
    "sns_topic_name": "snsTopicName",
    "software_token_mfa_configuration": "softwareTokenMfaConfiguration",
    "solution_stack_name": "solutionStackName",
    "source_account": "sourceAccount",
    "source_ami_id": "sourceAmiId",
    "source_ami_region": "sourceAmiRegion",
    "source_arn": "sourceArn",
    "source_backup_identifier": "sourceBackupIdentifier",
    "source_cidr_block": "sourceCidrBlock",
    "source_code_hash": "sourceCodeHash",
    "source_code_size": "sourceCodeSize",
    "source_db_cluster_identifier": "sourceDbClusterIdentifier",
    "source_db_cluster_snapshot_arn": "sourceDbClusterSnapshotArn",
    "source_db_snapshot_identifier": "sourceDbSnapshotIdentifier",
    "source_dest_check": "sourceDestCheck",
    "source_endpoint_arn": "sourceEndpointArn",
    "source_ids": "sourceIds",
    "source_instance_id": "sourceInstanceId",
    "source_location_arn": "sourceLocationArn",
    "source_port_range": "sourcePortRange",
    "source_region": "sourceRegion",
    "source_security_group": "sourceSecurityGroup",
    "source_security_group_id": "sourceSecurityGroupId",
    "source_snapshot_id": "sourceSnapshotId",
    "source_type": "sourceType",
    "source_version": "sourceVersion",
    "source_volume_arn": "sourceVolumeArn",
    "split_tunnel": "splitTunnel",
    "splunk_configuration": "splunkConfiguration",
    "spot_bid_status": "spotBidStatus",
    "spot_instance_id": "spotInstanceId",
    "spot_options": "spotOptions",
    "spot_price": "spotPrice",
    "spot_request_state": "spotRequestState",
    "spot_type": "spotType",
    "sql_injection_match_tuples": "sqlInjectionMatchTuples",
    "sql_version": "sqlVersion",
    "sqs_failure_feedback_role_arn": "sqsFailureFeedbackRoleArn",
    "sqs_success_feedback_role_arn": "sqsSuccessFeedbackRoleArn",
    "sqs_success_feedback_sample_rate": "sqsSuccessFeedbackSampleRate",
    "sqs_target": "sqsTarget",
    "sriov_net_support": "sriovNetSupport",
    "ssh_host_dsa_key_fingerprint": "sshHostDsaKeyFingerprint",
    "ssh_host_rsa_key_fingerprint": "sshHostRsaKeyFingerprint",
    "ssh_key_name": "sshKeyName",
    "ssh_public_key": "sshPublicKey",
    "ssh_public_key_id": "sshPublicKeyId",
    "ssh_username": "sshUsername",
    "ssl_configurations": "sslConfigurations",
    "ssl_mode": "sslMode",
    "ssl_policy": "sslPolicy",
    "stack_endpoint": "stackEndpoint",
    "stack_id": "stackId",
    "stack_set_id": "stackSetId",
    "stack_set_name": "stackSetName",
    "stage_description": "stageDescription",
    "stage_name": "stageName",
    "stage_variables": "stageVariables",
    "standards_arn": "standardsArn",
    "start_date": "startDate",
    "start_time": "startTime",
    "starting_position": "startingPosition",
    "starting_position_timestamp": "startingPositionTimestamp",
    "state_transition_reason": "stateTransitionReason",
    "statement_id": "statementId",
    "statement_id_prefix": "statementIdPrefix",
    "static_ip_name": "staticIpName",
    "static_members": "staticMembers",
    "static_routes_only": "staticRoutesOnly",
    "stats_enabled": "statsEnabled",
    "stats_password": "statsPassword",
    "stats_url": "statsUrl",
    "stats_user": "statsUser",
    "status_code": "statusCode",
    "status_reason": "statusReason",
    "step_adjustments": "stepAdjustments",
    "step_concurrency_level": "stepConcurrencyLevel",
    "step_functions": "stepFunctions",
    "step_scaling_policy_configuration": "stepScalingPolicyConfiguration",
    "stop_actions": "stopActions",
    "storage_capacity": "storageCapacity",
    "storage_class": "storageClass",
    "storage_class_analysis": "storageClassAnalysis",
    "storage_descriptor": "storageDescriptor",
    "storage_encrypted": "storageEncrypted",
    "storage_location": "storageLocation",
    "storage_type": "storageType",
    "stream_arn": "streamArn",
    "stream_enabled": "streamEnabled",
    "stream_label": "streamLabel",
    "stream_view_type": "streamViewType",
    "subject_alternative_names": "subjectAlternativeNames",
    "subnet_group_name": "subnetGroupName",
    "subnet_id": "subnetId",
    "subnet_ids": "subnetIds",
    "subnet_mappings": "subnetMappings",
    "success_feedback_role_arn": "successFeedbackRoleArn",
    "success_feedback_sample_rate": "successFeedbackSampleRate",
    "support_code": "supportCode",
    "supported_identity_providers": "supportedIdentityProviders",
    "supported_login_providers": "supportedLoginProviders",
    "suspended_processes": "suspendedProcesses",
    "system_packages": "systemPackages",
    "table_mappings": "tableMappings",
    "table_name": "tableName",
    "table_prefix": "tablePrefix",
    "table_type": "tableType",
    "tag_key_scope": "tagKeyScope",
    "tag_specifications": "tagSpecifications",
    "tag_value_scope": "tagValueScope",
    "tags_collection": "tagsCollection",
    "tape_drive_type": "tapeDriveType",
    "target_action": "targetAction",
    "target_arn": "targetArn",
    "target_capacity": "targetCapacity",
    "target_capacity_specification": "targetCapacitySpecification",
    "target_endpoint_arn": "targetEndpointArn",
    "target_group_arn": "targetGroupArn",
    "target_group_arns": "targetGroupArns",
    "target_id": "targetId",
    "target_ips": "targetIps",
    "target_key_arn": "targetKeyArn",
    "target_key_id": "targetKeyId",
    "target_name": "targetName",
    "target_network_cidr": "targetNetworkCidr",
    "target_pipeline": "targetPipeline",
    "target_tracking_configuration": "targetTrackingConfiguration",
    "target_tracking_scaling_policy_configuration": "targetTrackingScalingPolicyConfiguration",
    "target_type": "targetType",
    "target_vpc_subnet_id": "targetVpcSubnetId",
    "task_arn": "taskArn",
    "task_definition": "taskDefinition",
    "task_invocation_parameters": "taskInvocationParameters",
    "task_role_arn": "taskRoleArn",
    "task_type": "taskType",
    "team_id": "teamId",
    "template_body": "templateBody",
    "template_name": "templateName",
    "template_selection_expression": "templateSelectionExpression",
    "template_url": "templateUrl",
    "terminate_instances": "terminateInstances",
    "terminate_instances_with_expiration": "terminateInstancesWithExpiration",
    "termination_policies": "terminationPolicies",
    "termination_protection": "terminationProtection",
    "thing_type_name": "thingTypeName",
    "threshold_count": "thresholdCount",
    "threshold_metric_id": "thresholdMetricId",
    "throttle_settings": "throttleSettings",
    "throughput_capacity": "throughputCapacity",
    "throughput_mode": "throughputMode",
    "thumbnail_config": "thumbnailConfig",
    "thumbnail_config_permissions": "thumbnailConfigPermissions",
    "thumbprint_lists": "thumbprintLists",
    "time_period_end": "timePeriodEnd",
    "time_period_start": "timePeriodStart",
    "time_unit": "timeUnit",
    "timeout_in_minutes": "timeoutInMinutes",
    "timeout_in_seconds": "timeoutInSeconds",
    "timeout_milliseconds": "timeoutMilliseconds",
    "tls_config": "tlsConfig",
    "tls_policy": "tlsPolicy",
    "to_port": "toPort",
    "token_key": "tokenKey",
    "token_key_id": "tokenKeyId",
    "topic_arn": "topicArn",
    "tracing_config": "tracingConfig",
    "traffic_dial_percentage": "trafficDialPercentage",
    "traffic_direction": "trafficDirection",
    "traffic_mirror_filter_id": "trafficMirrorFilterId",
    "traffic_mirror_target_id": "trafficMirrorTargetId",
    "traffic_routing_config": "trafficRoutingConfig",
    "traffic_type": "trafficType",
    "transactional_messages_per_second": "transactionalMessagesPerSecond",
    "transit_encryption_enabled": "transitEncryptionEnabled",
    "transit_gateway_attachment_id": "transitGatewayAttachmentId",
    "transit_gateway_default_route_table_association": "transitGatewayDefaultRouteTableAssociation",
    "transit_gateway_default_route_table_propagation": "transitGatewayDefaultRouteTablePropagation",
    "transit_gateway_id": "transitGatewayId",
    "transit_gateway_route_table_id": "transitGatewayRouteTableId",
    "transitive_tag_keys": "transitiveTagKeys",
    "transport_protocol": "transportProtocol",
    "treat_missing_data": "treatMissingData",
    "trigger_configurations": "triggerConfigurations",
    "trigger_types": "triggerTypes",
    "trusted_signers": "trustedSigners",
    "tunnel1_address": "tunnel1Address",
    "tunnel1_bgp_asn": "tunnel1BgpAsn",
    "tunnel1_bgp_holdtime": "tunnel1BgpHoldtime",
    "tunnel1_cgw_inside_address": "tunnel1CgwInsideAddress",
    "tunnel1_inside_cidr": "tunnel1InsideCidr",
    "tunnel1_preshared_key": "tunnel1PresharedKey",
    "tunnel1_vgw_inside_address": "tunnel1VgwInsideAddress",
    "tunnel2_address": "tunnel2Address",
    "tunnel2_bgp_asn": "tunnel2BgpAsn",
    "tunnel2_bgp_holdtime": "tunnel2BgpHoldtime",
    "tunnel2_cgw_inside_address": "tunnel2CgwInsideAddress",
    "tunnel2_inside_cidr": "tunnel2InsideCidr",
    "tunnel2_preshared_key": "tunnel2PresharedKey",
    "tunnel2_vgw_inside_address": "tunnel2VgwInsideAddress",
    "unique_id": "uniqueId",
    "update_default_version": "updateDefaultVersion",
    "url_path": "urlPath",
    "usage_plan_id": "usagePlanId",
    "usage_report_s3_bucket": "usageReportS3Bucket",
    "use_custom_cookbooks": "useCustomCookbooks",
    "use_ebs_optimized_instances": "useEbsOptimizedInstances",
    "use_opsworks_security_groups": "useOpsworksSecurityGroups",
    "user_arn": "userArn",
    "user_data": "userData",
    "user_data_base64": "userDataBase64",
    "user_name": "userName",
    "user_pool_add_ons": "userPoolAddOns",
    "user_pool_config": "userPoolConfig",
    "user_pool_id": "userPoolId",
    "user_role": "userRole",
    "user_volume_encryption_enabled": "userVolumeEncryptionEnabled",
    "username_attributes": "usernameAttributes",
    "username_configuration": "usernameConfiguration",
    "valid_from": "validFrom",
    "valid_to": "validTo",
    "valid_until": "validUntil",
    "valid_user_lists": "validUserLists",
    "validate_request_body": "validateRequestBody",
    "validate_request_parameters": "validateRequestParameters",
    "validation_emails": "validationEmails",
    "validation_method": "validationMethod",
    "validation_record_fqdns": "validationRecordFqdns",
    "vault_name": "vaultName",
    "verification_message_template": "verificationMessageTemplate",
    "verification_token": "verificationToken",
    "version_id": "versionId",
    "version_stages": "versionStages",
    "vgw_telemetries": "vgwTelemetries",
    "video_codec_options": "videoCodecOptions",
    "video_watermarks": "videoWatermarks",
    "view_expanded_text": "viewExpandedText",
    "view_original_text": "viewOriginalText",
    "viewer_certificate": "viewerCertificate",
    "virtual_interface_id": "virtualInterfaceId",
    "virtual_network_id": "virtualNetworkId",
    "virtual_router_name": "virtualRouterName",
    "virtualization_type": "virtualizationType",
    "visibility_config": "visibilityConfig",
    "visibility_timeout_seconds": "visibilityTimeoutSeconds",
    "visible_to_all_users": "visibleToAllUsers",
    "volume_arn": "volumeArn",
    "volume_encryption_key": "volumeEncryptionKey",
    "volume_id": "volumeId",
    "volume_size": "volumeSize",
    "volume_size_in_bytes": "volumeSizeInBytes",
    "volume_tags": "volumeTags",
    "vpc_classic_link_id": "vpcClassicLinkId",
    "vpc_classic_link_security_groups": "vpcClassicLinkSecurityGroups",
    "vpc_config": "vpcConfig",
    "vpc_configuration": "vpcConfiguration",
    "vpc_endpoint_id": "vpcEndpointId",
    "vpc_endpoint_service_id": "vpcEndpointServiceId",
    "vpc_endpoint_type": "vpcEndpointType",
    "vpc_id": "vpcId",
    "vpc_options": "vpcOptions",
    "vpc_owner_id": "vpcOwnerId",
    "vpc_peering_connection_id": "vpcPeeringConnectionId",
    "vpc_region": "vpcRegion",
    "vpc_security_group_ids": "vpcSecurityGroupIds",
    "vpc_settings": "vpcSettings",
    "vpc_zone_identifiers": "vpcZoneIdentifiers",
    "vpn_connection_id": "vpnConnectionId",
    "vpn_ecmp_support": "vpnEcmpSupport",
    "vpn_gateway_id": "vpnGatewayId",
    "wait_for_capacity_timeout": "waitForCapacityTimeout",
    "wait_for_deployment": "waitForDeployment",
    "wait_for_elb_capacity": "waitForElbCapacity",
    "wait_for_fulfillment": "waitForFulfillment",
    "wait_for_ready_timeout": "waitForReadyTimeout",
    "wait_for_steady_state": "waitForSteadyState",
    "web_acl_arn": "webAclArn",
    "web_acl_id": "webAclId",
    "website_ca_id": "websiteCaId",
    "website_domain": "websiteDomain",
    "website_endpoint": "websiteEndpoint",
    "website_redirect": "websiteRedirect",
    "weekly_maintenance_start_time": "weeklyMaintenanceStartTime",
    "weighted_routing_policies": "weightedRoutingPolicies",
    "window_id": "windowId",
    "worker_type": "workerType",
    "workflow_execution_retention_period_in_days": "workflowExecutionRetentionPeriodInDays",
    "workflow_name": "workflowName",
    "workmail_actions": "workmailActions",
    "workspace_properties": "workspaceProperties",
    "workspace_security_group_id": "workspaceSecurityGroupId",
    "write_attributes": "writeAttributes",
    "write_capacity": "writeCapacity",
    "xml_classifier": "xmlClassifier",
    "xray_enabled": "xrayEnabled",
    "xray_tracing_enabled": "xrayTracingEnabled",
    "xss_match_tuples": "xssMatchTuples",
    "zone_id": "zoneId",
    "zookeeper_connect_string": "zookeeperConnectString",
}

CAMEL_TO_SNAKE_CASE_TABLE = {
    "accelerationStatus": "acceleration_status",
    "acceleratorArn": "accelerator_arn",
    "acceptStatus": "accept_status",
    "acceptanceRequired": "acceptance_required",
    "accessGroupId": "access_group_id",
    "accessKey": "access_key",
    "accessLogSettings": "access_log_settings",
    "accessLogs": "access_logs",
    "accessPolicies": "access_policies",
    "accessPolicy": "access_policy",
    "accessUrl": "access_url",
    "accountAggregationSource": "account_aggregation_source",
    "accountAlias": "account_alias",
    "accountId": "account_id",
    "actionsEnabled": "actions_enabled",
    "activatedRules": "activated_rules",
    "activationCode": "activation_code",
    "activationKey": "activation_key",
    "activeDirectoryId": "active_directory_id",
    "addHeaderActions": "add_header_actions",
    "additionalArtifacts": "additional_artifacts",
    "additionalAuthenticationProviders": "additional_authentication_providers",
    "additionalInfo": "additional_info",
    "additionalSchemaElements": "additional_schema_elements",
    "addressFamily": "address_family",
    "adjustmentType": "adjustment_type",
    "adminAccountId": "admin_account_id",
    "adminCreateUserConfig": "admin_create_user_config",
    "administrationRoleArn": "administration_role_arn",
    "advancedOptions": "advanced_options",
    "advancedSecurityOptions": "advanced_security_options",
    "agentArns": "agent_arns",
    "agentVersion": "agent_version",
    "alarmActions": "alarm_actions",
    "alarmConfiguration": "alarm_configuration",
    "alarmDescription": "alarm_description",
    "albTargetGroupArn": "alb_target_group_arn",
    "aliasAttributes": "alias_attributes",
    "allSettings": "all_settings",
    "allocatedMemory": "allocated_memory",
    "allocatedStorage": "allocated_storage",
    "allocationId": "allocation_id",
    "allocationStrategy": "allocation_strategy",
    "allowExternalPrincipals": "allow_external_principals",
    "allowMajorVersionUpgrade": "allow_major_version_upgrade",
    "allowOverwrite": "allow_overwrite",
    "allowReassociation": "allow_reassociation",
    "allowSelfManagement": "allow_self_management",
    "allowSsh": "allow_ssh",
    "allowSudo": "allow_sudo",
    "allowUnassociatedTargets": "allow_unassociated_targets",
    "allowUnauthenticatedIdentities": "allow_unauthenticated_identities",
    "allowUsersToChangePassword": "allow_users_to_change_password",
    "allowVersionUpgrade": "allow_version_upgrade",
    "allowedAccountIds": "allowed_account_ids",
    "allowedOauthFlows": "allowed_oauth_flows",
    "allowedOauthFlowsUserPoolClient": "allowed_oauth_flows_user_pool_client",
    "allowedOauthScopes": "allowed_oauth_scopes",
    "allowedPattern": "allowed_pattern",
    "allowedPrefixes": "allowed_prefixes",
    "allowedPrincipals": "allowed_principals",
    "amazonAddress": "amazon_address",
    "amazonSideAsn": "amazon_side_asn",
    "amiId": "ami_id",
    "amiType": "ami_type",
    "analyticsConfiguration": "analytics_configuration",
    "analyzerName": "analyzer_name",
    "apiEndpoint": "api_endpoint",
    "apiId": "api_id",
    "apiKey": "api_key",
    "apiKeyRequired": "api_key_required",
    "apiKeySelectionExpression": "api_key_selection_expression",
    "apiKeySource": "api_key_source",
    "apiMappingKey": "api_mapping_key",
    "apiMappingSelectionExpression": "api_mapping_selection_expression",
    "apiStages": "api_stages",
    "appName": "app_name",
    "appServer": "app_server",
    "appServerVersion": "app_server_version",
    "appSources": "app_sources",
    "applicationFailureFeedbackRoleArn": "application_failure_feedback_role_arn",
    "applicationId": "application_id",
    "applicationSuccessFeedbackRoleArn": "application_success_feedback_role_arn",
    "applicationSuccessFeedbackSampleRate": "application_success_feedback_sample_rate",
    "applyImmediately": "apply_immediately",
    "approvalRules": "approval_rules",
    "approvedPatches": "approved_patches",
    "approvedPatchesComplianceLevel": "approved_patches_compliance_level",
    "appversionLifecycle": "appversion_lifecycle",
    "arnSuffix": "arn_suffix",
    "artifactStore": "artifact_store",
    "assignGeneratedIpv6CidrBlock": "assign_generated_ipv6_cidr_block",
    "assignIpv6AddressOnCreation": "assign_ipv6_address_on_creation",
    "associatePublicIpAddress": "associate_public_ip_address",
    "associateWithPrivateIp": "associate_with_private_ip",
    "associatedGatewayId": "associated_gateway_id",
    "associatedGatewayOwnerAccountId": "associated_gateway_owner_account_id",
    "associatedGatewayType": "associated_gateway_type",
    "associationDefaultRouteTableId": "association_default_route_table_id",
    "associationId": "association_id",
    "associationName": "association_name",
    "assumeRole": "assume_role",
    "assumeRolePolicy": "assume_role_policy",
    "atRestEncryptionEnabled": "at_rest_encryption_enabled",
    "attachmentId": "attachment_id",
    "attachmentsSources": "attachments_sources",
    "attributeMapping": "attribute_mapping",
    "audioCodecOptions": "audio_codec_options",
    "auditStreamArn": "audit_stream_arn",
    "authToken": "auth_token",
    "authType": "auth_type",
    "authenticationConfiguration": "authentication_configuration",
    "authenticationOptions": "authentication_options",
    "authenticationType": "authentication_type",
    "authorizationScopes": "authorization_scopes",
    "authorizationType": "authorization_type",
    "authorizeAllGroups": "authorize_all_groups",
    "authorizerCredentials": "authorizer_credentials",
    "authorizerCredentialsArn": "authorizer_credentials_arn",
    "authorizerId": "authorizer_id",
    "authorizerResultTtlInSeconds": "authorizer_result_ttl_in_seconds",
    "authorizerType": "authorizer_type",
    "authorizerUri": "authorizer_uri",
    "autoAccept": "auto_accept",
    "autoAcceptSharedAttachments": "auto_accept_shared_attachments",
    "autoAssignElasticIps": "auto_assign_elastic_ips",
    "autoAssignPublicIps": "auto_assign_public_ips",
    "autoBundleOnDeploy": "auto_bundle_on_deploy",
    "autoDeploy": "auto_deploy",
    "autoDeployed": "auto_deployed",
    "autoEnable": "auto_enable",
    "autoHealing": "auto_healing",
    "autoMinorVersionUpgrade": "auto_minor_version_upgrade",
    "autoRollbackConfiguration": "auto_rollback_configuration",
    "autoScalingGroupProvider": "auto_scaling_group_provider",
    "autoScalingType": "auto_scaling_type",
    "autoVerifiedAttributes": "auto_verified_attributes",
    "automatedSnapshotRetentionPeriod": "automated_snapshot_retention_period",
    "automaticBackupRetentionDays": "automatic_backup_retention_days",
    "automaticFailoverEnabled": "automatic_failover_enabled",
    "automaticStopTimeMinutes": "automatic_stop_time_minutes",
    "automationTargetParameterName": "automation_target_parameter_name",
    "autoscalingGroupName": "autoscaling_group_name",
    "autoscalingGroups": "autoscaling_groups",
    "autoscalingPolicy": "autoscaling_policy",
    "autoscalingRole": "autoscaling_role",
    "availabilityZone": "availability_zone",
    "availabilityZoneId": "availability_zone_id",
    "availabilityZoneName": "availability_zone_name",
    "availabilityZones": "availability_zones",
    "awsAccountId": "aws_account_id",
    "awsDevice": "aws_device",
    "awsFlowRubySettings": "aws_flow_ruby_settings",
    "awsKmsKeyArn": "aws_kms_key_arn",
    "awsServiceAccessPrincipals": "aws_service_access_principals",
    "awsServiceName": "aws_service_name",
    "azMode": "az_mode",
    "backtrackWindow": "backtrack_window",
    "backupRetentionPeriod": "backup_retention_period",
    "backupWindow": "backup_window",
    "badgeEnabled": "badge_enabled",
    "badgeUrl": "badge_url",
    "baseEndpointDnsNames": "base_endpoint_dns_names",
    "basePath": "base_path",
    "baselineId": "baseline_id",
    "batchSize": "batch_size",
    "batchTarget": "batch_target",
    "behaviorOnMxFailure": "behavior_on_mx_failure",
    "berkshelfVersion": "berkshelf_version",
    "bgpAsn": "bgp_asn",
    "bgpAuthKey": "bgp_auth_key",
    "bgpPeerId": "bgp_peer_id",
    "bgpStatus": "bgp_status",
    "bidPrice": "bid_price",
    "billingMode": "billing_mode",
    "binaryMediaTypes": "binary_media_types",
    "bisectBatchOnFunctionError": "bisect_batch_on_function_error",
    "blockDeviceMappings": "block_device_mappings",
    "blockDurationMinutes": "block_duration_minutes",
    "blockPublicAcls": "block_public_acls",
    "blockPublicPolicy": "block_public_policy",
    "blueGreenDeploymentConfig": "blue_green_deployment_config",
    "blueprintId": "blueprint_id",
    "bootstrapActions": "bootstrap_actions",
    "bootstrapBrokers": "bootstrap_brokers",
    "bootstrapBrokersTls": "bootstrap_brokers_tls",
    "bounceActions": "bounce_actions",
    "branchFilter": "branch_filter",
    "brokerName": "broker_name",
    "brokerNodeGroupInfo": "broker_node_group_info",
    "bucketDomainName": "bucket_domain_name",
    "bucketName": "bucket_name",
    "bucketPrefix": "bucket_prefix",
    "bucketRegionalDomainName": "bucket_regional_domain_name",
    "budgetType": "budget_type",
    "buildId": "build_id",
    "buildTimeout": "build_timeout",
    "bundleId": "bundle_id",
    "bundlerVersion": "bundler_version",
    "byteMatchTuples": "byte_match_tuples",
    "caCertIdentifier": "ca_cert_identifier",
    "cacheClusterEnabled": "cache_cluster_enabled",
    "cacheClusterSize": "cache_cluster_size",
    "cacheControl": "cache_control",
    "cacheKeyParameters": "cache_key_parameters",
    "cacheNamespace": "cache_namespace",
    "cacheNodes": "cache_nodes",
    "cachingConfig": "caching_config",
    "callbackUrls": "callback_urls",
    "callerReference": "caller_reference",
    "campaignHook": "campaign_hook",
    "capacityProviderStrategies": "capacity_provider_strategies",
    "capacityProviders": "capacity_providers",
    "capacityReservationSpecification": "capacity_reservation_specification",
    "catalogId": "catalog_id",
    "catalogTargets": "catalog_targets",
    "cdcStartTime": "cdc_start_time",
    "certificateArn": "certificate_arn",
    "certificateAuthority": "certificate_authority",
    "certificateAuthorityArn": "certificate_authority_arn",
    "certificateAuthorityConfiguration": "certificate_authority_configuration",
    "certificateBody": "certificate_body",
    "certificateChain": "certificate_chain",
    "certificateId": "certificate_id",
    "certificateName": "certificate_name",
    "certificatePem": "certificate_pem",
    "certificatePrivateKey": "certificate_private_key",
    "certificateSigningRequest": "certificate_signing_request",
    "certificateUploadDate": "certificate_upload_date",
    "certificateWallet": "certificate_wallet",
    "channelId": "channel_id",
    "chapEnabled": "chap_enabled",
    "characterSetName": "character_set_name",
    "childHealthThreshold": "child_health_threshold",
    "childHealthchecks": "child_healthchecks",
    "cidrBlock": "cidr_block",
    "cidrBlocks": "cidr_blocks",
    "ciphertextBlob": "ciphertext_blob",
    "classificationType": "classification_type",
    "clientAffinity": "client_affinity",
    "clientAuthentication": "client_authentication",
    "clientCertificateId": "client_certificate_id",
    "clientCidrBlock": "client_cidr_block",
    "clientId": "client_id",
    "clientIdLists": "client_id_lists",
    "clientLists": "client_lists",
    "clientSecret": "client_secret",
    "clientToken": "client_token",
    "clientVpnEndpointId": "client_vpn_endpoint_id",
    "cloneUrlHttp": "clone_url_http",
    "cloneUrlSsh": "clone_url_ssh",
    "cloudWatchLogsGroupArn": "cloud_watch_logs_group_arn",
    "cloudWatchLogsRoleArn": "cloud_watch_logs_role_arn",
    "cloudfrontAccessIdentityPath": "cloudfront_access_identity_path",
    "cloudfrontDistributionArn": "cloudfront_distribution_arn",
    "cloudfrontDomainName": "cloudfront_domain_name",
    "cloudfrontZoneId": "cloudfront_zone_id",
    "cloudwatchAlarm": "cloudwatch_alarm",
    "cloudwatchAlarmName": "cloudwatch_alarm_name",
    "cloudwatchAlarmRegion": "cloudwatch_alarm_region",
    "cloudwatchDestinations": "cloudwatch_destinations",
    "cloudwatchLogGroupArn": "cloudwatch_log_group_arn",
    "cloudwatchLoggingOptions": "cloudwatch_logging_options",
    "cloudwatchMetric": "cloudwatch_metric",
    "cloudwatchRoleArn": "cloudwatch_role_arn",
    "clusterAddress": "cluster_address",
    "clusterCertificates": "cluster_certificates",
    "clusterConfig": "cluster_config",
    "clusterEndpointIdentifier": "cluster_endpoint_identifier",
    "clusterId": "cluster_id",
    "clusterIdentifier": "cluster_identifier",
    "clusterIdentifierPrefix": "cluster_identifier_prefix",
    "clusterMembers": "cluster_members",
    "clusterMode": "cluster_mode",
    "clusterName": "cluster_name",
    "clusterParameterGroupName": "cluster_parameter_group_name",
    "clusterPublicKey": "cluster_public_key",
    "clusterResourceId": "cluster_resource_id",
    "clusterRevisionNumber": "cluster_revision_number",
    "clusterSecurityGroups": "cluster_security_groups",
    "clusterState": "cluster_state",
    "clusterSubnetGroupName": "cluster_subnet_group_name",
    "clusterType": "cluster_type",
    "clusterVersion": "cluster_version",
    "cnamePrefix": "cname_prefix",
    "cognitoIdentityProviders": "cognito_identity_providers",
    "cognitoOptions": "cognito_options",
    "companyCode": "company_code",
    "comparisonOperator": "comparison_operator",
    "compatibleRuntimes": "compatible_runtimes",
    "completeLock": "complete_lock",
    "complianceSeverity": "compliance_severity",
    "computeEnvironmentName": "compute_environment_name",
    "computeEnvironmentNamePrefix": "compute_environment_name_prefix",
    "computeEnvironments": "compute_environments",
    "computePlatform": "compute_platform",
    "computeResources": "compute_resources",
    "computerName": "computer_name",
    "configurationEndpoint": "configuration_endpoint",
    "configurationEndpointAddress": "configuration_endpoint_address",
    "configurationId": "configuration_id",
    "configurationInfo": "configuration_info",
    "configurationManagerName": "configuration_manager_name",
    "configurationManagerVersion": "configuration_manager_version",
    "configurationSetName": "configuration_set_name",
    "configurationsJson": "configurations_json",
    "confirmationTimeoutInMinutes": "confirmation_timeout_in_minutes",
    "connectSettings": "connect_settings",
    "connectionDraining": "connection_draining",
    "connectionDrainingTimeout": "connection_draining_timeout",
    "connectionEvents": "connection_events",
    "connectionId": "connection_id",
    "connectionLogOptions": "connection_log_options",
    "connectionNotificationArn": "connection_notification_arn",
    "connectionProperties": "connection_properties",
    "connectionType": "connection_type",
    "connectionsBandwidth": "connections_bandwidth",
    "containerDefinitions": "container_definitions",
    "containerName": "container_name",
    "containerProperties": "container_properties",
    "contentBase64": "content_base64",
    "contentBasedDeduplication": "content_based_deduplication",
    "contentConfig": "content_config",
    "contentConfigPermissions": "content_config_permissions",
    "contentDisposition": "content_disposition",
    "contentEncoding": "content_encoding",
    "contentHandling": "content_handling",
    "contentHandlingStrategy": "content_handling_strategy",
    "contentLanguage": "content_language",
    "contentType": "content_type",
    "cookieExpirationPeriod": "cookie_expiration_period",
    "cookieName": "cookie_name",
    "copyTagsToBackups": "copy_tags_to_backups",
    "copyTagsToSnapshot": "copy_tags_to_snapshot",
    "coreInstanceGroup": "core_instance_group",
    "corsConfiguration": "cors_configuration",
    "corsRules": "cors_rules",
    "costFilters": "cost_filters",
    "costTypes": "cost_types",
    "cpuCoreCount": "cpu_core_count",
    "cpuCount": "cpu_count",
    "cpuOptions": "cpu_options",
    "cpuThreadsPerCore": "cpu_threads_per_core",
    "createDate": "create_date",
    "createTimestamp": "create_timestamp",
    "createdAt": "created_at",
    "createdDate": "created_date",
    "createdTime": "created_time",
    "creationDate": "creation_date",
    "creationTime": "creation_time",
    "creationToken": "creation_token",
    "credentialDuration": "credential_duration",
    "credentialsArn": "credentials_arn",
    "creditSpecification": "credit_specification",
    "crossZoneLoadBalancing": "cross_zone_load_balancing",
    "csvClassifier": "csv_classifier",
    "currentVersion": "current_version",
    "customAmiId": "custom_ami_id",
    "customConfigureRecipes": "custom_configure_recipes",
    "customCookbooksSources": "custom_cookbooks_sources",
    "customDeployRecipes": "custom_deploy_recipes",
    "customEndpointType": "custom_endpoint_type",
    "customErrorResponses": "custom_error_responses",
    "customInstanceProfileArn": "custom_instance_profile_arn",
    "customJson": "custom_json",
    "customSecurityGroupIds": "custom_security_group_ids",
    "customSetupRecipes": "custom_setup_recipes",
    "customShutdownRecipes": "custom_shutdown_recipes",
    "customSuffix": "custom_suffix",
    "customUndeployRecipes": "custom_undeploy_recipes",
    "customerAddress": "customer_address",
    "customerAwsId": "customer_aws_id",
    "customerGatewayConfiguration": "customer_gateway_configuration",
    "customerGatewayId": "customer_gateway_id",
    "customerMasterKeySpec": "customer_master_key_spec",
    "customerOwnedIp": "customer_owned_ip",
    "customerOwnedIpv4Pool": "customer_owned_ipv4_pool",
    "customerUserName": "customer_user_name",
    "dailyAutomaticBackupStartTime": "daily_automatic_backup_start_time",
    "dashboardArn": "dashboard_arn",
    "dashboardBody": "dashboard_body",
    "dashboardName": "dashboard_name",
    "dataEncryptionKeyId": "data_encryption_key_id",
    "dataRetentionInHours": "data_retention_in_hours",
    "dataSource": "data_source",
    "dataSourceArn": "data_source_arn",
    "dataSourceDatabaseName": "data_source_database_name",
    "dataSourceType": "data_source_type",
    "dataType": "data_type",
    "databaseName": "database_name",
    "datapointsToAlarm": "datapoints_to_alarm",
    "dbClusterIdentifier": "db_cluster_identifier",
    "dbClusterParameterGroupName": "db_cluster_parameter_group_name",
    "dbClusterSnapshotArn": "db_cluster_snapshot_arn",
    "dbClusterSnapshotIdentifier": "db_cluster_snapshot_identifier",
    "dbInstanceIdentifier": "db_instance_identifier",
    "dbParameterGroupName": "db_parameter_group_name",
    "dbPassword": "db_password",
    "dbSnapshotArn": "db_snapshot_arn",
    "dbSnapshotIdentifier": "db_snapshot_identifier",
    "dbSubnetGroupName": "db_subnet_group_name",
    "dbUser": "db_user",
    "dbiResourceId": "dbi_resource_id",
    "deadLetterConfig": "dead_letter_config",
    "defaultAction": "default_action",
    "defaultActions": "default_actions",
    "defaultArguments": "default_arguments",
    "defaultAssociationRouteTable": "default_association_route_table",
    "defaultAuthenticationMethod": "default_authentication_method",
    "defaultAvailabilityZone": "default_availability_zone",
    "defaultBranch": "default_branch",
    "defaultCacheBehavior": "default_cache_behavior",
    "defaultCapacityProviderStrategies": "default_capacity_provider_strategies",
    "defaultClientId": "default_client_id",
    "defaultCooldown": "default_cooldown",
    "defaultInstanceProfileArn": "default_instance_profile_arn",
    "defaultNetworkAclId": "default_network_acl_id",
    "defaultOs": "default_os",
    "defaultPropagationRouteTable": "default_propagation_route_table",
    "defaultRedirectUri": "default_redirect_uri",
    "defaultResult": "default_result",
    "defaultRootDeviceType": "default_root_device_type",
    "defaultRootObject": "default_root_object",
    "defaultRouteSettings": "default_route_settings",
    "defaultRouteTableAssociation": "default_route_table_association",
    "defaultRouteTableId": "default_route_table_id",
    "defaultRouteTablePropagation": "default_route_table_propagation",
    "defaultRunProperties": "default_run_properties",
    "defaultSecurityGroupId": "default_security_group_id",
    "defaultSenderId": "default_sender_id",
    "defaultSmsType": "default_sms_type",
    "defaultSshKeyName": "default_ssh_key_name",
    "defaultStorageClass": "default_storage_class",
    "defaultSubnetId": "default_subnet_id",
    "defaultValue": "default_value",
    "defaultVersion": "default_version",
    "defaultVersionId": "default_version_id",
    "delaySeconds": "delay_seconds",
    "delegationSetId": "delegation_set_id",
    "deleteAutomatedBackups": "delete_automated_backups",
    "deleteEbs": "delete_ebs",
    "deleteEip": "delete_eip",
    "deletionProtection": "deletion_protection",
    "deletionWindowInDays": "deletion_window_in_days",
    "deliveryPolicy": "delivery_policy",
    "deliveryStatusIamRoleArn": "delivery_status_iam_role_arn",
    "deliveryStatusSuccessSamplingRate": "delivery_status_success_sampling_rate",
    "deploymentConfigId": "deployment_config_id",
    "deploymentConfigName": "deployment_config_name",
    "deploymentController": "deployment_controller",
    "deploymentGroupName": "deployment_group_name",
    "deploymentId": "deployment_id",
    "deploymentMaximumPercent": "deployment_maximum_percent",
    "deploymentMinimumHealthyPercent": "deployment_minimum_healthy_percent",
    "deploymentMode": "deployment_mode",
    "deploymentStyle": "deployment_style",
    "deploymentType": "deployment_type",
    "deregistrationDelay": "deregistration_delay",
    "desiredCapacity": "desired_capacity",
    "desiredCount": "desired_count",
    "destinationArn": "destination_arn",
    "destinationCidrBlock": "destination_cidr_block",
    "destinationConfig": "destination_config",
    "destinationId": "destination_id",
    "destinationIpv6CidrBlock": "destination_ipv6_cidr_block",
    "destinationLocationArn": "destination_location_arn",
    "destinationName": "destination_name",
    "destinationPortRange": "destination_port_range",
    "destinationPrefixListId": "destination_prefix_list_id",
    "destinationStreamArn": "destination_stream_arn",
    "detailType": "detail_type",
    "detectorId": "detector_id",
    "developerProviderName": "developer_provider_name",
    "deviceCaCertificate": "device_ca_certificate",
    "deviceConfiguration": "device_configuration",
    "deviceIndex": "device_index",
    "deviceName": "device_name",
    "dhcpOptionsId": "dhcp_options_id",
    "directInternetAccess": "direct_internet_access",
    "directoryId": "directory_id",
    "directoryName": "directory_name",
    "directoryType": "directory_type",
    "disableApiTermination": "disable_api_termination",
    "disableEmailNotification": "disable_email_notification",
    "disableRollback": "disable_rollback",
    "diskId": "disk_id",
    "diskSize": "disk_size",
    "displayName": "display_name",
    "dkimTokens": "dkim_tokens",
    "dnsConfig": "dns_config",
    "dnsEntries": "dns_entries",
    "dnsIpAddresses": "dns_ip_addresses",
    "dnsIps": "dns_ips",
    "dnsName": "dns_name",
    "dnsServers": "dns_servers",
    "dnsSupport": "dns_support",
    "documentFormat": "document_format",
    "documentRoot": "document_root",
    "documentType": "document_type",
    "documentVersion": "document_version",
    "documentationVersion": "documentation_version",
    "domainEndpointOptions": "domain_endpoint_options",
    "domainIamRoleName": "domain_iam_role_name",
    "domainId": "domain_id",
    "domainName": "domain_name",
    "domainNameConfiguration": "domain_name_configuration",
    "domainNameServers": "domain_name_servers",
    "domainValidationOptions": "domain_validation_options",
    "drainElbOnShutdown": "drain_elb_on_shutdown",
    "dropInvalidHeaderFields": "drop_invalid_header_fields",
    "durationSeconds": "duration_seconds",
    "dxGatewayAssociationId": "dx_gateway_association_id",
    "dxGatewayId": "dx_gateway_id",
    "dxGatewayOwnerAccountId": "dx_gateway_owner_account_id",
    "dynamodbConfig": "dynamodb_config",
    "dynamodbTargets": "dynamodb_targets",
    "ebsBlockDevices": "ebs_block_devices",
    "ebsConfigs": "ebs_configs",
    "ebsOptimized": "ebs_optimized",
    "ebsOptions": "ebs_options",
    "ebsRootVolumeSize": "ebs_root_volume_size",
    "ebsVolumes": "ebs_volumes",
    "ec2Attributes": "ec2_attributes",
    "ec2Config": "ec2_config",
    "ec2InboundPermissions": "ec2_inbound_permissions",
    "ec2InstanceId": "ec2_instance_id",
    "ec2InstanceType": "ec2_instance_type",
    "ec2TagFilters": "ec2_tag_filters",
    "ec2TagSets": "ec2_tag_sets",
    "ecsClusterArn": "ecs_cluster_arn",
    "ecsService": "ecs_service",
    "ecsTarget": "ecs_target",
    "efsFileSystemArn": "efs_file_system_arn",
    "egressOnlyGatewayId": "egress_only_gateway_id",
    "elasticGpuSpecifications": "elastic_gpu_specifications",
    "elasticInferenceAccelerator": "elastic_inference_accelerator",
    "elasticIp": "elastic_ip",
    "elasticLoadBalancer": "elastic_load_balancer",
    "elasticsearchConfig": "elasticsearch_config",
    "elasticsearchConfiguration": "elasticsearch_configuration",
    "elasticsearchSettings": "elasticsearch_settings",
    "elasticsearchVersion": "elasticsearch_version",
    "emailConfiguration": "email_configuration",
    "emailVerificationMessage": "email_verification_message",
    "emailVerificationSubject": "email_verification_subject",
    "enaSupport": "ena_support",
    "enableClassiclink": "enable_classiclink",
    "enableClassiclinkDnsSupport": "enable_classiclink_dns_support",
    "enableCloudwatchLogsExports": "enable_cloudwatch_logs_exports",
    "enableCrossZoneLoadBalancing": "enable_cross_zone_load_balancing",
    "enableDeletionProtection": "enable_deletion_protection",
    "enableDnsHostnames": "enable_dns_hostnames",
    "enableDnsSupport": "enable_dns_support",
    "enableEcsManagedTags": "enable_ecs_managed_tags",
    "enableHttp2": "enable_http2",
    "enableHttpEndpoint": "enable_http_endpoint",
    "enableKeyRotation": "enable_key_rotation",
    "enableLogFileValidation": "enable_log_file_validation",
    "enableLogging": "enable_logging",
    "enableMonitoring": "enable_monitoring",
    "enableNetworkIsolation": "enable_network_isolation",
    "enableSni": "enable_sni",
    "enableSsl": "enable_ssl",
    "enableSso": "enable_sso",
    "enabledCloudwatchLogsExports": "enabled_cloudwatch_logs_exports",
    "enabledClusterLogTypes": "enabled_cluster_log_types",
    "enabledMetrics": "enabled_metrics",
    "enabledPolicyTypes": "enabled_policy_types",
    "encodedKey": "encoded_key",
    "encryptAtRest": "encrypt_at_rest",
    "encryptedFingerprint": "encrypted_fingerprint",
    "encryptedPassword": "encrypted_password",
    "encryptedPrivateKey": "encrypted_private_key",
    "encryptedSecret": "encrypted_secret",
    "encryptionConfig": "encryption_config",
    "encryptionConfiguration": "encryption_configuration",
    "encryptionConfigurations": "encryption_configurations",
    "encryptionInfo": "encryption_info",
    "encryptionKey": "encryption_key",
    "encryptionOptions": "encryption_options",
    "encryptionType": "encryption_type",
    "endDate": "end_date",
    "endDateType": "end_date_type",
    "endTime": "end_time",
    "endpointArn": "endpoint_arn",
    "endpointAutoConfirms": "endpoint_auto_confirms",
    "endpointConfigName": "endpoint_config_name",
    "endpointConfiguration": "endpoint_configuration",
    "endpointConfigurations": "endpoint_configurations",
    "endpointDetails": "endpoint_details",
    "endpointGroupRegion": "endpoint_group_region",
    "endpointId": "endpoint_id",
    "endpointType": "endpoint_type",
    "endpointUrl": "endpoint_url",
    "enforceConsumerDeletion": "enforce_consumer_deletion",
    "engineMode": "engine_mode",
    "engineName": "engine_name",
    "engineType": "engine_type",
    "engineVersion": "engine_version",
    "enhancedMonitoring": "enhanced_monitoring",
    "enhancedVpcRouting": "enhanced_vpc_routing",
    "eniId": "eni_id",
    "environmentId": "environment_id",
    "ephemeralBlockDevices": "ephemeral_block_devices",
    "ephemeralStorage": "ephemeral_storage",
    "errorAction": "error_action",
    "estimatedInstanceWarmup": "estimated_instance_warmup",
    "evaluateLowSampleCountPercentiles": "evaluate_low_sample_count_percentiles",
    "evaluationPeriods": "evaluation_periods",
    "eventCategories": "event_categories",
    "eventDeliveryFailureTopicArn": "event_delivery_failure_topic_arn",
    "eventEndpointCreatedTopicArn": "event_endpoint_created_topic_arn",
    "eventEndpointDeletedTopicArn": "event_endpoint_deleted_topic_arn",
    "eventEndpointUpdatedTopicArn": "event_endpoint_updated_topic_arn",
    "eventPattern": "event_pattern",
    "eventSelectors": "event_selectors",
    "eventSourceArn": "event_source_arn",
    "eventSourceToken": "event_source_token",
    "eventTypeIds": "event_type_ids",
    "excessCapacityTerminationPolicy": "excess_capacity_termination_policy",
    "excludedAccounts": "excluded_accounts",
    "excludedMembers": "excluded_members",
    "executionArn": "execution_arn",
    "executionProperty": "execution_property",
    "executionRoleArn": "execution_role_arn",
    "executionRoleName": "execution_role_name",
    "expirationDate": "expiration_date",
    "expirationModel": "expiration_model",
    "expirePasswords": "expire_passwords",
    "explicitAuthFlows": "explicit_auth_flows",
    "exportPath": "export_path",
    "extendedS3Configuration": "extended_s3_configuration",
    "extendedStatistic": "extended_statistic",
    "externalId": "external_id",
    "extraConnectionAttributes": "extra_connection_attributes",
    "failoverRoutingPolicies": "failover_routing_policies",
    "failureFeedbackRoleArn": "failure_feedback_role_arn",
    "failureThreshold": "failure_threshold",
    "fargateProfileName": "fargate_profile_name",
    "featureName": "feature_name",
    "featureSet": "feature_set",
    "fifoQueue": "fifo_queue",
    "fileSystemArn": "file_system_arn",
    "fileSystemConfig": "file_system_config",
    "fileSystemId": "file_system_id",
    "fileshareId": "fileshare_id",
    "filterGroups": "filter_groups",
    "filterPattern": "filter_pattern",
    "filterPolicy": "filter_policy",
    "finalSnapshotIdentifier": "final_snapshot_identifier",
    "findingPublishingFrequency": "finding_publishing_frequency",
    "fixedRate": "fixed_rate",
    "fleetArn": "fleet_arn",
    "fleetType": "fleet_type",
    "forbiddenAccountIds": "forbidden_account_ids",
    "forceDelete": "force_delete",
    "forceDestroy": "force_destroy",
    "forceDetach": "force_detach",
    "forceDetachPolicies": "force_detach_policies",
    "forceNewDeployment": "force_new_deployment",
    "forceUpdateVersion": "force_update_version",
    "fromAddress": "from_address",
    "fromPort": "from_port",
    "functionArn": "function_arn",
    "functionId": "function_id",
    "functionName": "function_name",
    "functionVersion": "function_version",
    "gatewayArn": "gateway_arn",
    "gatewayId": "gateway_id",
    "gatewayIpAddress": "gateway_ip_address",
    "gatewayName": "gateway_name",
    "gatewayTimezone": "gateway_timezone",
    "gatewayType": "gateway_type",
    "gatewayVpcEndpoint": "gateway_vpc_endpoint",
    "generateSecret": "generate_secret",
    "geoMatchConstraints": "geo_match_constraints",
    "geolocationRoutingPolicies": "geolocation_routing_policies",
    "getPasswordData": "get_password_data",
    "globalClusterIdentifier": "global_cluster_identifier",
    "globalClusterMembers": "global_cluster_members",
    "globalClusterResourceId": "global_cluster_resource_id",
    "globalFilters": "global_filters",
    "globalSecondaryIndexes": "global_secondary_indexes",
    "glueVersion": "glue_version",
    "grantCreationTokens": "grant_creation_tokens",
    "grantId": "grant_id",
    "grantToken": "grant_token",
    "granteePrincipal": "grantee_principal",
    "grokClassifier": "grok_classifier",
    "groupName": "group_name",
    "groupNames": "group_names",
    "guessMimeTypeEnabled": "guess_mime_type_enabled",
    "hardExpiry": "hard_expiry",
    "hasLogicalRedundancy": "has_logical_redundancy",
    "hasPublicAccessPolicy": "has_public_access_policy",
    "hashKey": "hash_key",
    "hashType": "hash_type",
    "healthCheck": "health_check",
    "healthCheckConfig": "health_check_config",
    "healthCheckCustomConfig": "health_check_custom_config",
    "healthCheckGracePeriod": "health_check_grace_period",
    "healthCheckGracePeriodSeconds": "health_check_grace_period_seconds",
    "healthCheckId": "health_check_id",
    "healthCheckIntervalSeconds": "health_check_interval_seconds",
    "healthCheckPath": "health_check_path",
    "healthCheckPort": "health_check_port",
    "healthCheckProtocol": "health_check_protocol",
    "healthCheckType": "health_check_type",
    "healthcheckMethod": "healthcheck_method",
    "healthcheckUrl": "healthcheck_url",
    "heartbeatTimeout": "heartbeat_timeout",
    "hibernationOptions": "hibernation_options",
    "hlsIngests": "hls_ingests",
    "homeDirectory": "home_directory",
    "homeRegion": "home_region",
    "hostId": "host_id",
    "hostInstanceType": "host_instance_type",
    "hostKey": "host_key",
    "hostKeyFingerprint": "host_key_fingerprint",
    "hostVpcId": "host_vpc_id",
    "hostedZone": "hosted_zone",
    "hostedZoneId": "hosted_zone_id",
    "hostnameTheme": "hostname_theme",
    "hsmEniId": "hsm_eni_id",
    "hsmId": "hsm_id",
    "hsmState": "hsm_state",
    "hsmType": "hsm_type",
    "httpConfig": "http_config",
    "httpFailureFeedbackRoleArn": "http_failure_feedback_role_arn",
    "httpMethod": "http_method",
    "httpSuccessFeedbackRoleArn": "http_success_feedback_role_arn",
    "httpSuccessFeedbackSampleRate": "http_success_feedback_sample_rate",
    "httpVersion": "http_version",
    "iamArn": "iam_arn",
    "iamDatabaseAuthenticationEnabled": "iam_database_authentication_enabled",
    "iamFleetRole": "iam_fleet_role",
    "iamInstanceProfile": "iam_instance_profile",
    "iamRole": "iam_role",
    "iamRoleArn": "iam_role_arn",
    "iamRoleId": "iam_role_id",
    "iamRoles": "iam_roles",
    "iamUserAccessToBilling": "iam_user_access_to_billing",
    "icmpCode": "icmp_code",
    "icmpType": "icmp_type",
    "identifierPrefix": "identifier_prefix",
    "identityPoolId": "identity_pool_id",
    "identityPoolName": "identity_pool_name",
    "identityProvider": "identity_provider",
    "identityProviderType": "identity_provider_type",
    "identitySource": "identity_source",
    "identitySources": "identity_sources",
    "identityType": "identity_type",
    "identityValidationExpression": "identity_validation_expression",
    "idleTimeout": "idle_timeout",
    "idpIdentifiers": "idp_identifiers",
    "ignoreDeletionError": "ignore_deletion_error",
    "ignorePublicAcls": "ignore_public_acls",
    "ignoreTags": "ignore_tags",
    "imageId": "image_id",
    "imageLocation": "image_location",
    "imageScanningConfiguration": "image_scanning_configuration",
    "imageTagMutability": "image_tag_mutability",
    "importPath": "import_path",
    "importedFileChunkSize": "imported_file_chunk_size",
    "inProgressValidationBatches": "in_progress_validation_batches",
    "includeGlobalServiceEvents": "include_global_service_events",
    "includeOriginalHeaders": "include_original_headers",
    "includedObjectVersions": "included_object_versions",
    "inferenceAccelerators": "inference_accelerators",
    "infrastructureClass": "infrastructure_class",
    "initialLifecycleHooks": "initial_lifecycle_hooks",
    "inputBucket": "input_bucket",
    "inputParameters": "input_parameters",
    "inputPath": "input_path",
    "inputTransformer": "input_transformer",
    "installUpdatesOnBoot": "install_updates_on_boot",
    "instanceClass": "instance_class",
    "instanceCount": "instance_count",
    "instanceId": "instance_id",
    "instanceInitiatedShutdownBehavior": "instance_initiated_shutdown_behavior",
    "instanceInterruptionBehaviour": "instance_interruption_behaviour",
    "instanceMarketOptions": "instance_market_options",
    "instanceMatchCriteria": "instance_match_criteria",
    "instanceName": "instance_name",
    "instanceOwnerId": "instance_owner_id",
    "instancePlatform": "instance_platform",
    "instancePoolsToUseCount": "instance_pools_to_use_count",
    "instancePort": "instance_port",
    "instancePorts": "instance_ports",
    "instanceProfileArn": "instance_profile_arn",
    "instanceRoleArn": "instance_role_arn",
    "instanceShutdownTimeout": "instance_shutdown_timeout",
    "instanceState": "instance_state",
    "instanceTenancy": "instance_tenancy",
    "instanceType": "instance_type",
    "instanceTypes": "instance_types",
    "insufficientDataActions": "insufficient_data_actions",
    "insufficientDataHealthStatus": "insufficient_data_health_status",
    "integrationHttpMethod": "integration_http_method",
    "integrationId": "integration_id",
    "integrationMethod": "integration_method",
    "integrationResponseKey": "integration_response_key",
    "integrationResponseSelectionExpression": "integration_response_selection_expression",
    "integrationType": "integration_type",
    "integrationUri": "integration_uri",
    "invalidUserLists": "invalid_user_lists",
    "invertHealthcheck": "invert_healthcheck",
    "invitationArn": "invitation_arn",
    "invitationMessage": "invitation_message",
    "invocationRole": "invocation_role",
    "invokeArn": "invoke_arn",
    "invokeUrl": "invoke_url",
    "iotAnalytics": "iot_analytics",
    "iotEvents": "iot_events",
    "ipAddress": "ip_address",
    "ipAddressType": "ip_address_type",
    "ipAddressVersion": "ip_address_version",
    "ipAddresses": "ip_addresses",
    "ipGroupIds": "ip_group_ids",
    "ipSetDescriptors": "ip_set_descriptors",
    "ipSets": "ip_sets",
    "ipcMode": "ipc_mode",
    "ipv6Address": "ipv6_address",
    "ipv6AddressCount": "ipv6_address_count",
    "ipv6Addresses": "ipv6_addresses",
    "ipv6AssociationId": "ipv6_association_id",
    "ipv6CidrBlock": "ipv6_cidr_block",
    "ipv6CidrBlockAssociationId": "ipv6_cidr_block_association_id",
    "ipv6CidrBlocks": "ipv6_cidr_blocks",
    "ipv6Support": "ipv6_support",
    "isEnabled": "is_enabled",
    "isIpv6Enabled": "is_ipv6_enabled",
    "isMultiRegionTrail": "is_multi_region_trail",
    "isOrganizationTrail": "is_organization_trail",
    "isStaticIp": "is_static_ip",
    "jdbcTargets": "jdbc_targets",
    "joinedMethod": "joined_method",
    "joinedTimestamp": "joined_timestamp",
    "jsonClassifier": "json_classifier",
    "jumboFrameCapable": "jumbo_frame_capable",
    "jvmOptions": "jvm_options",
    "jvmType": "jvm_type",
    "jvmVersion": "jvm_version",
    "jwtConfiguration": "jwt_configuration",
    "kafkaSettings": "kafka_settings",
    "kafkaVersion": "kafka_version",
    "kafkaVersions": "kafka_versions",
    "keepJobFlowAliveWhenNoSteps": "keep_job_flow_alive_when_no_steps",
    "kerberosAttributes": "kerberos_attributes",
    "kernelId": "kernel_id",
    "keyArn": "key_arn",
    "keyFingerprint": "key_fingerprint",
    "keyId": "key_id",
    "keyMaterialBase64": "key_material_base64",
    "keyName": "key_name",
    "keyNamePrefix": "key_name_prefix",
    "keyPairId": "key_pair_id",
    "keyPairName": "key_pair_name",
    "keyPrefixes": "key_prefixes",
    "keyState": "key_state",
    "keyType": "key_type",
    "keyUsage": "key_usage",
    "kibanaEndpoint": "kibana_endpoint",
    "kinesisDestination": "kinesis_destination",
    "kinesisSettings": "kinesis_settings",
    "kinesisSourceConfiguration": "kinesis_source_configuration",
    "kinesisTarget": "kinesis_target",
    "kmsDataKeyReusePeriodSeconds": "kms_data_key_reuse_period_seconds",
    "kmsEncrypted": "kms_encrypted",
    "kmsKeyArn": "kms_key_arn",
    "kmsKeyId": "kms_key_id",
    "kmsMasterKeyId": "kms_master_key_id",
    "lagId": "lag_id",
    "lambda": "lambda_",
    "lambdaActions": "lambda_actions",
    "lambdaConfig": "lambda_config",
    "lambdaFailureFeedbackRoleArn": "lambda_failure_feedback_role_arn",
    "lambdaFunctionArn": "lambda_function_arn",
    "lambdaFunctions": "lambda_functions",
    "lambdaMultiValueHeadersEnabled": "lambda_multi_value_headers_enabled",
    "lambdaSuccessFeedbackRoleArn": "lambda_success_feedback_role_arn",
    "lambdaSuccessFeedbackSampleRate": "lambda_success_feedback_sample_rate",
    "lastModified": "last_modified",
    "lastModifiedDate": "last_modified_date",
    "lastModifiedTime": "last_modified_time",
    "lastProcessingResult": "last_processing_result",
    "lastServiceErrorId": "last_service_error_id",
    "lastUpdateTimestamp": "last_update_timestamp",
    "lastUpdatedDate": "last_updated_date",
    "lastUpdatedTime": "last_updated_time",
    "latencyRoutingPolicies": "latency_routing_policies",
    "latestRevision": "latest_revision",
    "latestVersion": "latest_version",
    "launchConfiguration": "launch_configuration",
    "launchConfigurations": "launch_configurations",
    "launchGroup": "launch_group",
    "launchSpecifications": "launch_specifications",
    "launchTemplate": "launch_template",
    "launchTemplateConfig": "launch_template_config",
    "launchTemplateConfigs": "launch_template_configs",
    "launchType": "launch_type",
    "layerArn": "layer_arn",
    "layerIds": "layer_ids",
    "layerName": "layer_name",
    "lbPort": "lb_port",
    "licenseConfigurationArn": "license_configuration_arn",
    "licenseCount": "license_count",
    "licenseCountHardLimit": "license_count_hard_limit",
    "licenseCountingType": "license_counting_type",
    "licenseInfo": "license_info",
    "licenseModel": "license_model",
    "licenseRules": "license_rules",
    "licenseSpecifications": "license_specifications",
    "lifecycleConfigName": "lifecycle_config_name",
    "lifecyclePolicy": "lifecycle_policy",
    "lifecycleRules": "lifecycle_rules",
    "lifecycleTransition": "lifecycle_transition",
    "limitAmount": "limit_amount",
    "limitUnit": "limit_unit",
    "listenerArn": "listener_arn",
    "loadBalancer": "load_balancer",
    "loadBalancerArn": "load_balancer_arn",
    "loadBalancerInfo": "load_balancer_info",
    "loadBalancerName": "load_balancer_name",
    "loadBalancerPort": "load_balancer_port",
    "loadBalancerType": "load_balancer_type",
    "loadBalancers": "load_balancers",
    "loadBalancingAlgorithmType": "load_balancing_algorithm_type",
    "localGatewayId": "local_gateway_id",
    "localGatewayRouteTableId": "local_gateway_route_table_id",
    "localGatewayVirtualInterfaceGroupId": "local_gateway_virtual_interface_group_id",
    "localSecondaryIndexes": "local_secondary_indexes",
    "locationArn": "location_arn",
    "locationUri": "location_uri",
    "lockToken": "lock_token",
    "logConfig": "log_config",
    "logDestination": "log_destination",
    "logDestinationConfigs": "log_destination_configs",
    "logDestinationType": "log_destination_type",
    "logFormat": "log_format",
    "logGroup": "log_group",
    "logGroupName": "log_group_name",
    "logPaths": "log_paths",
    "logPublishingOptions": "log_publishing_options",
    "logUri": "log_uri",
    "loggingConfig": "logging_config",
    "loggingConfiguration": "logging_configuration",
    "loggingInfo": "logging_info",
    "loggingRole": "logging_role",
    "logoutUrls": "logout_urls",
    "logsConfig": "logs_config",
    "lunNumber": "lun_number",
    "macAddress": "mac_address",
    "mailFromDomain": "mail_from_domain",
    "mainRouteTableId": "main_route_table_id",
    "maintenanceWindow": "maintenance_window",
    "maintenanceWindowStartTime": "maintenance_window_start_time",
    "majorEngineVersion": "major_engine_version",
    "manageBerkshelf": "manage_berkshelf",
    "manageBundler": "manage_bundler",
    "manageEbsSnapshots": "manage_ebs_snapshots",
    "managesVpcEndpoints": "manages_vpc_endpoints",
    "mapPublicIpOnLaunch": "map_public_ip_on_launch",
    "masterAccountArn": "master_account_arn",
    "masterAccountEmail": "master_account_email",
    "masterAccountId": "master_account_id",
    "masterId": "master_id",
    "masterInstanceGroup": "master_instance_group",
    "masterPassword": "master_password",
    "masterPublicDns": "master_public_dns",
    "masterUsername": "master_username",
    "matchCriterias": "match_criterias",
    "matchingTypes": "matching_types",
    "maxAggregationInterval": "max_aggregation_interval",
    "maxAllocatedStorage": "max_allocated_storage",
    "maxCapacity": "max_capacity",
    "maxConcurrency": "max_concurrency",
    "maxErrors": "max_errors",
    "maxInstanceLifetime": "max_instance_lifetime",
    "maxMessageSize": "max_message_size",
    "maxPasswordAge": "max_password_age",
    "maxRetries": "max_retries",
    "maxSessionDuration": "max_session_duration",
    "maxSize": "max_size",
    "maximumBatchingWindowInSeconds": "maximum_batching_window_in_seconds",
    "maximumEventAgeInSeconds": "maximum_event_age_in_seconds",
    "maximumExecutionFrequency": "maximum_execution_frequency",
    "maximumRecordAgeInSeconds": "maximum_record_age_in_seconds",
    "maximumRetryAttempts": "maximum_retry_attempts",
    "measureLatency": "measure_latency",
    "mediaType": "media_type",
    "mediumChangerType": "medium_changer_type",
    "memberAccountId": "member_account_id",
    "memberClusters": "member_clusters",
    "memberStatus": "member_status",
    "memorySize": "memory_size",
    "meshName": "mesh_name",
    "messageRetentionSeconds": "message_retention_seconds",
    "messagesPerSecond": "messages_per_second",
    "metadataOptions": "metadata_options",
    "methodPath": "method_path",
    "metricAggregationType": "metric_aggregation_type",
    "metricGroups": "metric_groups",
    "metricName": "metric_name",
    "metricQueries": "metric_queries",
    "metricTransformation": "metric_transformation",
    "metricsGranularity": "metrics_granularity",
    "mfaConfiguration": "mfa_configuration",
    "migrationType": "migration_type",
    "minAdjustmentMagnitude": "min_adjustment_magnitude",
    "minCapacity": "min_capacity",
    "minElbCapacity": "min_elb_capacity",
    "minSize": "min_size",
    "minimumCompressionSize": "minimum_compression_size",
    "minimumHealthyHosts": "minimum_healthy_hosts",
    "minimumPasswordLength": "minimum_password_length",
    "mixedInstancesPolicy": "mixed_instances_policy",
    "modelSelectionExpression": "model_selection_expression",
    "mongodbSettings": "mongodb_settings",
    "monitoringInterval": "monitoring_interval",
    "monitoringRoleArn": "monitoring_role_arn",
    "monthlySpendLimit": "monthly_spend_limit",
    "mountOptions": "mount_options",
    "mountTargetDnsName": "mount_target_dns_name",
    "multiAttachEnabled": "multi_attach_enabled",
    "multiAz": "multi_az",
    "multivalueAnswerRoutingPolicy": "multivalue_answer_routing_policy",
    "namePrefix": "name_prefix",
    "nameServers": "name_servers",
    "namespaceId": "namespace_id",
    "natGatewayId": "nat_gateway_id",
    "neptuneClusterParameterGroupName": "neptune_cluster_parameter_group_name",
    "neptuneParameterGroupName": "neptune_parameter_group_name",
    "neptuneSubnetGroupName": "neptune_subnet_group_name",
    "netbiosNameServers": "netbios_name_servers",
    "netbiosNodeType": "netbios_node_type",
    "networkAclId": "network_acl_id",
    "networkConfiguration": "network_configuration",
    "networkInterface": "network_interface",
    "networkInterfaceId": "network_interface_id",
    "networkInterfaceIds": "network_interface_ids",
    "networkInterfacePort": "network_interface_port",
    "networkInterfaces": "network_interfaces",
    "networkLoadBalancerArn": "network_load_balancer_arn",
    "networkLoadBalancerArns": "network_load_balancer_arns",
    "networkMode": "network_mode",
    "networkOrigin": "network_origin",
    "networkServices": "network_services",
    "newGameSessionProtectionPolicy": "new_game_session_protection_policy",
    "nfsFileShareDefaults": "nfs_file_share_defaults",
    "nodeGroupName": "node_group_name",
    "nodeRoleArn": "node_role_arn",
    "nodeToNodeEncryption": "node_to_node_encryption",
    "nodeType": "node_type",
    "nodejsVersion": "nodejs_version",
    "nonMasterAccounts": "non_master_accounts",
    "notAfter": "not_after",
    "notBefore": "not_before",
    "notificationArns": "notification_arns",
    "notificationMetadata": "notification_metadata",
    "notificationProperty": "notification_property",
    "notificationTargetArn": "notification_target_arn",
    "notificationTopicArn": "notification_topic_arn",
    "notificationType": "notification_type",
    "ntpServers": "ntp_servers",
    "numCacheNodes": "num_cache_nodes",
    "numberCacheClusters": "number_cache_clusters",
    "numberOfBrokerNodes": "number_of_broker_nodes",
    "numberOfNodes": "number_of_nodes",
    "numberOfWorkers": "number_of_workers",
    "objectAcl": "object_acl",
    "objectLockConfiguration": "object_lock_configuration",
    "objectLockLegalHoldStatus": "object_lock_legal_hold_status",
    "objectLockMode": "object_lock_mode",
    "objectLockRetainUntilDate": "object_lock_retain_until_date",
    "okActions": "ok_actions",
    "onCreate": "on_create",
    "onDemandOptions": "on_demand_options",
    "onFailure": "on_failure",
    "onPremConfig": "on_prem_config",
    "onPremisesInstanceTagFilters": "on_premises_instance_tag_filters",
    "onStart": "on_start",
    "openMonitoring": "open_monitoring",
    "openidConnectConfig": "openid_connect_config",
    "openidConnectProviderArns": "openid_connect_provider_arns",
    "operatingSystem": "operating_system",
    "operationName": "operation_name",
    "optInStatus": "opt_in_status",
    "optimizeForEndUserLocation": "optimize_for_end_user_location",
    "optionGroupDescription": "option_group_description",
    "optionGroupName": "option_group_name",
    "optionalFields": "optional_fields",
    "orderedCacheBehaviors": "ordered_cache_behaviors",
    "orderedPlacementStrategies": "ordered_placement_strategies",
    "organizationAggregationSource": "organization_aggregation_source",
    "originGroups": "origin_groups",
    "originalRouteTableId": "original_route_table_id",
    "outpostArn": "outpost_arn",
    "outputBucket": "output_bucket",
    "outputLocation": "output_location",
    "ownerAccount": "owner_account",
    "ownerAccountId": "owner_account_id",
    "ownerAlias": "owner_alias",
    "ownerArn": "owner_arn",
    "ownerId": "owner_id",
    "ownerInformation": "owner_information",
    "owningAccount": "owning_account",
    "packetLength": "packet_length",
    "parallelizationFactor": "parallelization_factor",
    "parameterGroupName": "parameter_group_name",
    "parameterOverrides": "parameter_overrides",
    "parentId": "parent_id",
    "partitionKeys": "partition_keys",
    "passengerVersion": "passenger_version",
    "passthroughBehavior": "passthrough_behavior",
    "passwordData": "password_data",
    "passwordLength": "password_length",
    "passwordPolicy": "password_policy",
    "passwordResetRequired": "password_reset_required",
    "passwordReusePrevention": "password_reuse_prevention",
    "patchGroup": "patch_group",
    "pathPart": "path_part",
    "payloadFormatVersion": "payload_format_version",
    "payloadUrl": "payload_url",
    "peerAccountId": "peer_account_id",
    "peerOwnerId": "peer_owner_id",
    "peerRegion": "peer_region",
    "peerTransitGatewayId": "peer_transit_gateway_id",
    "peerVpcId": "peer_vpc_id",
    "pemEncodedCertificate": "pem_encoded_certificate",
    "perUnitStorageThroughput": "per_unit_storage_throughput",
    "performanceInsightsEnabled": "performance_insights_enabled",
    "performanceInsightsKmsKeyId": "performance_insights_kms_key_id",
    "performanceInsightsRetentionPeriod": "performance_insights_retention_period",
    "performanceMode": "performance_mode",
    "permanentDeletionTimeInDays": "permanent_deletion_time_in_days",
    "permissionsBoundary": "permissions_boundary",
    "pgpKey": "pgp_key",
    "physicalConnectionRequirements": "physical_connection_requirements",
    "pidMode": "pid_mode",
    "pipelineConfig": "pipeline_config",
    "placementConstraints": "placement_constraints",
    "placementGroup": "placement_group",
    "placementGroupId": "placement_group_id",
    "placementTenancy": "placement_tenancy",
    "planId": "plan_id",
    "platformArn": "platform_arn",
    "platformCredential": "platform_credential",
    "platformPrincipal": "platform_principal",
    "platformTypes": "platform_types",
    "platformVersion": "platform_version",
    "playerLatencyPolicies": "player_latency_policies",
    "podExecutionRoleArn": "pod_execution_role_arn",
    "pointInTimeRecovery": "point_in_time_recovery",
    "policyArn": "policy_arn",
    "policyArns": "policy_arns",
    "policyAttributes": "policy_attributes",
    "policyBody": "policy_body",
    "policyDetails": "policy_details",
    "policyDocument": "policy_document",
    "policyId": "policy_id",
    "policyName": "policy_name",
    "policyNames": "policy_names",
    "policyType": "policy_type",
    "policyTypeName": "policy_type_name",
    "policyUrl": "policy_url",
    "pollInterval": "poll_interval",
    "portRanges": "port_ranges",
    "posixUser": "posix_user",
    "preferredAvailabilityZones": "preferred_availability_zones",
    "preferredBackupWindow": "preferred_backup_window",
    "preferredFileServerIp": "preferred_file_server_ip",
    "preferredMaintenanceWindow": "preferred_maintenance_window",
    "preferredSubnetId": "preferred_subnet_id",
    "prefixListId": "prefix_list_id",
    "prefixListIds": "prefix_list_ids",
    "preventUserExistenceErrors": "prevent_user_existence_errors",
    "priceClass": "price_class",
    "pricingPlan": "pricing_plan",
    "primaryContainer": "primary_container",
    "primaryEndpointAddress": "primary_endpoint_address",
    "primaryNetworkInterfaceId": "primary_network_interface_id",
    "principalArn": "principal_arn",
    "privateDns": "private_dns",
    "privateDnsEnabled": "private_dns_enabled",
    "privateDnsName": "private_dns_name",
    "privateIp": "private_ip",
    "privateIpAddress": "private_ip_address",
    "privateIps": "private_ips",
    "privateIpsCount": "private_ips_count",
    "privateKey": "private_key",
    "productArn": "product_arn",
    "productCode": "product_code",
    "productionVariants": "production_variants",
    "projectName": "project_name",
    "promotionTier": "promotion_tier",
    "promotionalMessagesPerSecond": "promotional_messages_per_second",
    "propagateTags": "propagate_tags",
    "propagatingVgws": "propagating_vgws",
    "propagationDefaultRouteTableId": "propagation_default_route_table_id",
    "proposalId": "proposal_id",
    "protectFromScaleIn": "protect_from_scale_in",
    "protocolType": "protocol_type",
    "providerArns": "provider_arns",
    "providerDetails": "provider_details",
    "providerName": "provider_name",
    "providerType": "provider_type",
    "provisionedConcurrentExecutions": "provisioned_concurrent_executions",
    "provisionedThroughputInMibps": "provisioned_throughput_in_mibps",
    "proxyConfiguration": "proxy_configuration",
    "proxyProtocolV2": "proxy_protocol_v2",
    "publicAccessBlockConfiguration": "public_access_block_configuration",
    "publicDns": "public_dns",
    "publicIp": "public_ip",
    "publicIpAddress": "public_ip_address",
    "publicIpv4Pool": "public_ipv4_pool",
    "publicKey": "public_key",
    "publiclyAccessible": "publicly_accessible",
    "qualifiedArn": "qualified_arn",
    "queueUrl": "queue_url",
    "queuedTimeout": "queued_timeout",
    "quietTime": "quiet_time",
    "quotaCode": "quota_code",
    "quotaName": "quota_name",
    "quotaSettings": "quota_settings",
    "railsEnv": "rails_env",
    "ramDiskId": "ram_disk_id",
    "ramSize": "ram_size",
    "ramdiskId": "ramdisk_id",
    "rangeKey": "range_key",
    "rateKey": "rate_key",
    "rateLimit": "rate_limit",
    "rawMessageDelivery": "raw_message_delivery",
    "rdsDbInstanceArn": "rds_db_instance_arn",
    "readAttributes": "read_attributes",
    "readCapacity": "read_capacity",
    "readOnly": "read_only",
    "readerEndpoint": "reader_endpoint",
    "receiveWaitTimeSeconds": "receive_wait_time_seconds",
    "receiverAccountId": "receiver_account_id",
    "recordingGroup": "recording_group",
    "recoveryPoints": "recovery_points",
    "recoveryWindowInDays": "recovery_window_in_days",
    "redactedFields": "redacted_fields",
    "redrivePolicy": "redrive_policy",
    "redshiftConfiguration": "redshift_configuration",
    "referenceDataSources": "reference_data_sources",
    "referenceName": "reference_name",
    "refreshTokenValidity": "refresh_token_validity",
    "regexMatchTuples": "regex_match_tuples",
    "regexPatternStrings": "regex_pattern_strings",
    "regionalCertificateArn": "regional_certificate_arn",
    "regionalCertificateName": "regional_certificate_name",
    "regionalDomainName": "regional_domain_name",
    "regionalZoneId": "regional_zone_id",
    "registeredBy": "registered_by",
    "registrationCode": "registration_code",
    "registrationCount": "registration_count",
    "registrationLimit": "registration_limit",
    "registryId": "registry_id",
    "regularExpressions": "regular_expressions",
    "rejectedPatches": "rejected_patches",
    "relationshipStatus": "relationship_status",
    "releaseLabel": "release_label",
    "releaseVersion": "release_version",
    "remoteAccess": "remote_access",
    "remoteAdministrationEndpoint": "remote_administration_endpoint",
    "remoteDomainName": "remote_domain_name",
    "replaceUnhealthyInstances": "replace_unhealthy_instances",
    "replicateSourceDb": "replicate_source_db",
    "replicationConfiguration": "replication_configuration",
    "replicationFactor": "replication_factor",
    "replicationGroupDescription": "replication_group_description",
    "replicationGroupId": "replication_group_id",
    "replicationInstanceArn": "replication_instance_arn",
    "replicationInstanceClass": "replication_instance_class",
    "replicationInstanceId": "replication_instance_id",
    "replicationInstancePrivateIps": "replication_instance_private_ips",
    "replicationInstancePublicIps": "replication_instance_public_ips",
    "replicationSourceIdentifier": "replication_source_identifier",
    "replicationSubnetGroupArn": "replication_subnet_group_arn",
    "replicationSubnetGroupDescription": "replication_subnet_group_description",
    "replicationSubnetGroupId": "replication_subnet_group_id",
    "replicationTaskArn": "replication_task_arn",
    "replicationTaskId": "replication_task_id",
    "replicationTaskSettings": "replication_task_settings",
    "reportName": "report_name",
    "reportedAgentVersion": "reported_agent_version",
    "reportedOsFamily": "reported_os_family",
    "reportedOsName": "reported_os_name",
    "reportedOsVersion": "reported_os_version",
    "repositoryId": "repository_id",
    "repositoryName": "repository_name",
    "repositoryUrl": "repository_url",
    "requestId": "request_id",
    "requestInterval": "request_interval",
    "requestMappingTemplate": "request_mapping_template",
    "requestModels": "request_models",
    "requestParameters": "request_parameters",
    "requestPayer": "request_payer",
    "requestStatus": "request_status",
    "requestTemplate": "request_template",
    "requestTemplates": "request_templates",
    "requestValidatorId": "request_validator_id",
    "requesterManaged": "requester_managed",
    "requesterPays": "requester_pays",
    "requireLowercaseCharacters": "require_lowercase_characters",
    "requireNumbers": "require_numbers",
    "requireSymbols": "require_symbols",
    "requireUppercaseCharacters": "require_uppercase_characters",
    "requiresCompatibilities": "requires_compatibilities",
    "reservationPlanSettings": "reservation_plan_settings",
    "reservedConcurrentExecutions": "reserved_concurrent_executions",
    "reservoirSize": "reservoir_size",
    "resolverEndpointId": "resolver_endpoint_id",
    "resolverRuleId": "resolver_rule_id",
    "resourceArn": "resource_arn",
    "resourceCreationLimitPolicy": "resource_creation_limit_policy",
    "resourceGroupArn": "resource_group_arn",
    "resourceId": "resource_id",
    "resourceIdScope": "resource_id_scope",
    "resourcePath": "resource_path",
    "resourceQuery": "resource_query",
    "resourceShareArn": "resource_share_arn",
    "resourceType": "resource_type",
    "resourceTypesScopes": "resource_types_scopes",
    "responseMappingTemplate": "response_mapping_template",
    "responseModels": "response_models",
    "responseParameters": "response_parameters",
    "responseTemplate": "response_template",
    "responseTemplates": "response_templates",
    "responseType": "response_type",
    "restApi": "rest_api",
    "restApiId": "rest_api_id",
    "restrictPublicBuckets": "restrict_public_buckets",
    "retainOnDelete": "retain_on_delete",
    "retainStack": "retain_stack",
    "retentionInDays": "retention_in_days",
    "retentionPeriod": "retention_period",
    "retireOnDelete": "retire_on_delete",
    "retiringPrincipal": "retiring_principal",
    "retryStrategy": "retry_strategy",
    "revocationConfiguration": "revocation_configuration",
    "revokeRulesOnDelete": "revoke_rules_on_delete",
    "roleArn": "role_arn",
    "roleMappings": "role_mappings",
    "roleName": "role_name",
    "rootBlockDevice": "root_block_device",
    "rootBlockDevices": "root_block_devices",
    "rootDeviceName": "root_device_name",
    "rootDeviceType": "root_device_type",
    "rootDeviceVolumeId": "root_device_volume_id",
    "rootDirectory": "root_directory",
    "rootPassword": "root_password",
    "rootPasswordOnAllInstances": "root_password_on_all_instances",
    "rootResourceId": "root_resource_id",
    "rootSnapshotId": "root_snapshot_id",
    "rootVolumeEncryptionEnabled": "root_volume_encryption_enabled",
    "rotationEnabled": "rotation_enabled",
    "rotationLambdaArn": "rotation_lambda_arn",
    "rotationRules": "rotation_rules",
    "routeFilterPrefixes": "route_filter_prefixes",
    "routeId": "route_id",
    "routeKey": "route_key",
    "routeResponseKey": "route_response_key",
    "routeResponseSelectionExpression": "route_response_selection_expression",
    "routeSelectionExpression": "route_selection_expression",
    "routeSettings": "route_settings",
    "routeTableId": "route_table_id",
    "routeTableIds": "route_table_ids",
    "routingConfig": "routing_config",
    "routingStrategy": "routing_strategy",
    "rubyVersion": "ruby_version",
    "rubygemsVersion": "rubygems_version",
    "ruleAction": "rule_action",
    "ruleId": "rule_id",
    "ruleIdentifier": "rule_identifier",
    "ruleName": "rule_name",
    "ruleNumber": "rule_number",
    "ruleSetName": "rule_set_name",
    "ruleType": "rule_type",
    "rulesPackageArns": "rules_package_arns",
    "runCommandTargets": "run_command_targets",
    "runningInstanceCount": "running_instance_count",
    "runtimeConfiguration": "runtime_configuration",
    "s3Actions": "s3_actions",
    "s3Bucket": "s3_bucket",
    "s3BucketArn": "s3_bucket_arn",
    "s3BucketName": "s3_bucket_name",
    "s3CanonicalUserId": "s3_canonical_user_id",
    "s3Config": "s3_config",
    "s3Configuration": "s3_configuration",
    "s3Destination": "s3_destination",
    "s3ForcePathStyle": "s3_force_path_style",
    "s3Import": "s3_import",
    "s3Key": "s3_key",
    "s3KeyPrefix": "s3_key_prefix",
    "s3ObjectVersion": "s3_object_version",
    "s3Prefix": "s3_prefix",
    "s3Region": "s3_region",
    "s3Settings": "s3_settings",
    "s3Targets": "s3_targets",
    "samlMetadataDocument": "saml_metadata_document",
    "samlProviderArns": "saml_provider_arns",
    "scalableDimension": "scalable_dimension",
    "scalableTargetAction": "scalable_target_action",
    "scaleDownBehavior": "scale_down_behavior",
    "scalingAdjustment": "scaling_adjustment",
    "scalingConfig": "scaling_config",
    "scalingConfiguration": "scaling_configuration",
    "scanEnabled": "scan_enabled",
    "scheduleExpression": "schedule_expression",
    "scheduleIdentifier": "schedule_identifier",
    "scheduleTimezone": "schedule_timezone",
    "scheduledActionName": "scheduled_action_name",
    "schedulingStrategy": "scheduling_strategy",
    "schemaChangePolicy": "schema_change_policy",
    "schemaVersion": "schema_version",
    "scopeIdentifiers": "scope_identifiers",
    "searchString": "search_string",
    "secondaryArtifacts": "secondary_artifacts",
    "secondaryPrivateIps": "secondary_private_ips",
    "secondarySources": "secondary_sources",
    "secretBinary": "secret_binary",
    "secretId": "secret_id",
    "secretKey": "secret_key",
    "secretString": "secret_string",
    "securityConfiguration": "security_configuration",
    "securityGroupId": "security_group_id",
    "securityGroupIds": "security_group_ids",
    "securityGroupNames": "security_group_names",
    "securityGroups": "security_groups",
    "securityPolicy": "security_policy",
    "selectionPattern": "selection_pattern",
    "selectionTags": "selection_tags",
    "selfManagedActiveDirectory": "self_managed_active_directory",
    "selfServicePermissions": "self_service_permissions",
    "senderAccountId": "sender_account_id",
    "senderId": "sender_id",
    "serverCertificateArn": "server_certificate_arn",
    "serverHostname": "server_hostname",
    "serverId": "server_id",
    "serverName": "server_name",
    "serverProperties": "server_properties",
    "serverSideEncryption": "server_side_encryption",
    "serverSideEncryptionConfiguration": "server_side_encryption_configuration",
    "serverType": "server_type",
    "serviceAccessRole": "service_access_role",
    "serviceCode": "service_code",
    "serviceLinkedRoleArn": "service_linked_role_arn",
    "serviceName": "service_name",
    "serviceNamespace": "service_namespace",
    "serviceRegistries": "service_registries",
    "serviceRole": "service_role",
    "serviceRoleArn": "service_role_arn",
    "serviceType": "service_type",
    "sesSmtpPasswordV4": "ses_smtp_password_v4",
    "sessionName": "session_name",
    "sessionNumber": "session_number",
    "setIdentifier": "set_identifier",
    "shardCount": "shard_count",
    "shardLevelMetrics": "shard_level_metrics",
    "shareArn": "share_arn",
    "shareId": "share_id",
    "shareName": "share_name",
    "shareStatus": "share_status",
    "sharedCredentialsFile": "shared_credentials_file",
    "shortCode": "short_code",
    "shortName": "short_name",
    "sizeConstraints": "size_constraints",
    "skipCredentialsValidation": "skip_credentials_validation",
    "skipDestroy": "skip_destroy",
    "skipFinalBackup": "skip_final_backup",
    "skipFinalSnapshot": "skip_final_snapshot",
    "skipGetEc2Platforms": "skip_get_ec2_platforms",
    "skipMetadataApiCheck": "skip_metadata_api_check",
    "skipRegionValidation": "skip_region_validation",
    "skipRequestingAccountId": "skip_requesting_account_id",
    "slowStart": "slow_start",
    "smbActiveDirectorySettings": "smb_active_directory_settings",
    "smbGuestPassword": "smb_guest_password",
    "smsAuthenticationMessage": "sms_authentication_message",
    "smsConfiguration": "sms_configuration",
    "smsVerificationMessage": "sms_verification_message",
    "snapshotArns": "snapshot_arns",
    "snapshotClusterIdentifier": "snapshot_cluster_identifier",
    "snapshotCopy": "snapshot_copy",
    "snapshotCopyGrantName": "snapshot_copy_grant_name",
    "snapshotDeliveryProperties": "snapshot_delivery_properties",
    "snapshotId": "snapshot_id",
    "snapshotIdentifier": "snapshot_identifier",
    "snapshotName": "snapshot_name",
    "snapshotOptions": "snapshot_options",
    "snapshotRetentionLimit": "snapshot_retention_limit",
    "snapshotType": "snapshot_type",
    "snapshotWindow": "snapshot_window",
    "snapshotWithoutReboot": "snapshot_without_reboot",
    "snsActions": "sns_actions",
    "snsDestination": "sns_destination",
    "snsTopic": "sns_topic",
    "snsTopicArn": "sns_topic_arn",
    "snsTopicName": "sns_topic_name",
    "softwareTokenMfaConfiguration": "software_token_mfa_configuration",
    "solutionStackName": "solution_stack_name",
    "sourceAccount": "source_account",
    "sourceAmiId": "source_ami_id",
    "sourceAmiRegion": "source_ami_region",
    "sourceArn": "source_arn",
    "sourceBackupIdentifier": "source_backup_identifier",
    "sourceCidrBlock": "source_cidr_block",
    "sourceCodeHash": "source_code_hash",
    "sourceCodeSize": "source_code_size",
    "sourceDbClusterIdentifier": "source_db_cluster_identifier",
    "sourceDbClusterSnapshotArn": "source_db_cluster_snapshot_arn",
    "sourceDbSnapshotIdentifier": "source_db_snapshot_identifier",
    "sourceDestCheck": "source_dest_check",
    "sourceEndpointArn": "source_endpoint_arn",
    "sourceIds": "source_ids",
    "sourceInstanceId": "source_instance_id",
    "sourceLocationArn": "source_location_arn",
    "sourcePortRange": "source_port_range",
    "sourceRegion": "source_region",
    "sourceSecurityGroup": "source_security_group",
    "sourceSecurityGroupId": "source_security_group_id",
    "sourceSnapshotId": "source_snapshot_id",
    "sourceType": "source_type",
    "sourceVersion": "source_version",
    "sourceVolumeArn": "source_volume_arn",
    "splitTunnel": "split_tunnel",
    "splunkConfiguration": "splunk_configuration",
    "spotBidStatus": "spot_bid_status",
    "spotInstanceId": "spot_instance_id",
    "spotOptions": "spot_options",
    "spotPrice": "spot_price",
    "spotRequestState": "spot_request_state",
    "spotType": "spot_type",
    "sqlInjectionMatchTuples": "sql_injection_match_tuples",
    "sqlVersion": "sql_version",
    "sqsFailureFeedbackRoleArn": "sqs_failure_feedback_role_arn",
    "sqsSuccessFeedbackRoleArn": "sqs_success_feedback_role_arn",
    "sqsSuccessFeedbackSampleRate": "sqs_success_feedback_sample_rate",
    "sqsTarget": "sqs_target",
    "sriovNetSupport": "sriov_net_support",
    "sshHostDsaKeyFingerprint": "ssh_host_dsa_key_fingerprint",
    "sshHostRsaKeyFingerprint": "ssh_host_rsa_key_fingerprint",
    "sshKeyName": "ssh_key_name",
    "sshPublicKey": "ssh_public_key",
    "sshPublicKeyId": "ssh_public_key_id",
    "sshUsername": "ssh_username",
    "sslConfigurations": "ssl_configurations",
    "sslMode": "ssl_mode",
    "sslPolicy": "ssl_policy",
    "stackEndpoint": "stack_endpoint",
    "stackId": "stack_id",
    "stackSetId": "stack_set_id",
    "stackSetName": "stack_set_name",
    "stageDescription": "stage_description",
    "stageName": "stage_name",
    "stageVariables": "stage_variables",
    "standardsArn": "standards_arn",
    "startDate": "start_date",
    "startTime": "start_time",
    "startingPosition": "starting_position",
    "startingPositionTimestamp": "starting_position_timestamp",
    "stateTransitionReason": "state_transition_reason",
    "statementId": "statement_id",
    "statementIdPrefix": "statement_id_prefix",
    "staticIpName": "static_ip_name",
    "staticMembers": "static_members",
    "staticRoutesOnly": "static_routes_only",
    "statsEnabled": "stats_enabled",
    "statsPassword": "stats_password",
    "statsUrl": "stats_url",
    "statsUser": "stats_user",
    "statusCode": "status_code",
    "statusReason": "status_reason",
    "stepAdjustments": "step_adjustments",
    "stepConcurrencyLevel": "step_concurrency_level",
    "stepFunctions": "step_functions",
    "stepScalingPolicyConfiguration": "step_scaling_policy_configuration",
    "stopActions": "stop_actions",
    "storageCapacity": "storage_capacity",
    "storageClass": "storage_class",
    "storageClassAnalysis": "storage_class_analysis",
    "storageDescriptor": "storage_descriptor",
    "storageEncrypted": "storage_encrypted",
    "storageLocation": "storage_location",
    "storageType": "storage_type",
    "streamArn": "stream_arn",
    "streamEnabled": "stream_enabled",
    "streamLabel": "stream_label",
    "streamViewType": "stream_view_type",
    "subjectAlternativeNames": "subject_alternative_names",
    "subnetGroupName": "subnet_group_name",
    "subnetId": "subnet_id",
    "subnetIds": "subnet_ids",
    "subnetMappings": "subnet_mappings",
    "successFeedbackRoleArn": "success_feedback_role_arn",
    "successFeedbackSampleRate": "success_feedback_sample_rate",
    "supportCode": "support_code",
    "supportedIdentityProviders": "supported_identity_providers",
    "supportedLoginProviders": "supported_login_providers",
    "suspendedProcesses": "suspended_processes",
    "systemPackages": "system_packages",
    "tableMappings": "table_mappings",
    "tableName": "table_name",
    "tablePrefix": "table_prefix",
    "tableType": "table_type",
    "tagKeyScope": "tag_key_scope",
    "tagSpecifications": "tag_specifications",
    "tagValueScope": "tag_value_scope",
    "tagsCollection": "tags_collection",
    "tapeDriveType": "tape_drive_type",
    "targetAction": "target_action",
    "targetArn": "target_arn",
    "targetCapacity": "target_capacity",
    "targetCapacitySpecification": "target_capacity_specification",
    "targetEndpointArn": "target_endpoint_arn",
    "targetGroupArn": "target_group_arn",
    "targetGroupArns": "target_group_arns",
    "targetId": "target_id",
    "targetIps": "target_ips",
    "targetKeyArn": "target_key_arn",
    "targetKeyId": "target_key_id",
    "targetName": "target_name",
    "targetNetworkCidr": "target_network_cidr",
    "targetPipeline": "target_pipeline",
    "targetTrackingConfiguration": "target_tracking_configuration",
    "targetTrackingScalingPolicyConfiguration": "target_tracking_scaling_policy_configuration",
    "targetType": "target_type",
    "targetVpcSubnetId": "target_vpc_subnet_id",
    "taskArn": "task_arn",
    "taskDefinition": "task_definition",
    "taskInvocationParameters": "task_invocation_parameters",
    "taskRoleArn": "task_role_arn",
    "taskType": "task_type",
    "teamId": "team_id",
    "templateBody": "template_body",
    "templateName": "template_name",
    "templateSelectionExpression": "template_selection_expression",
    "templateUrl": "template_url",
    "terminateInstances": "terminate_instances",
    "terminateInstancesWithExpiration": "terminate_instances_with_expiration",
    "terminationPolicies": "termination_policies",
    "terminationProtection": "termination_protection",
    "thingTypeName": "thing_type_name",
    "thresholdCount": "threshold_count",
    "thresholdMetricId": "threshold_metric_id",
    "throttleSettings": "throttle_settings",
    "throughputCapacity": "throughput_capacity",
    "throughputMode": "throughput_mode",
    "thumbnailConfig": "thumbnail_config",
    "thumbnailConfigPermissions": "thumbnail_config_permissions",
    "thumbprintLists": "thumbprint_lists",
    "timePeriodEnd": "time_period_end",
    "timePeriodStart": "time_period_start",
    "timeUnit": "time_unit",
    "timeoutInMinutes": "timeout_in_minutes",
    "timeoutInSeconds": "timeout_in_seconds",
    "timeoutMilliseconds": "timeout_milliseconds",
    "tlsConfig": "tls_config",
    "tlsPolicy": "tls_policy",
    "toPort": "to_port",
    "tokenKey": "token_key",
    "tokenKeyId": "token_key_id",
    "topicArn": "topic_arn",
    "tracingConfig": "tracing_config",
    "trafficDialPercentage": "traffic_dial_percentage",
    "trafficDirection": "traffic_direction",
    "trafficMirrorFilterId": "traffic_mirror_filter_id",
    "trafficMirrorTargetId": "traffic_mirror_target_id",
    "trafficRoutingConfig": "traffic_routing_config",
    "trafficType": "traffic_type",
    "transactionalMessagesPerSecond": "transactional_messages_per_second",
    "transitEncryptionEnabled": "transit_encryption_enabled",
    "transitGatewayAttachmentId": "transit_gateway_attachment_id",
    "transitGatewayDefaultRouteTableAssociation": "transit_gateway_default_route_table_association",
    "transitGatewayDefaultRouteTablePropagation": "transit_gateway_default_route_table_propagation",
    "transitGatewayId": "transit_gateway_id",
    "transitGatewayRouteTableId": "transit_gateway_route_table_id",
    "transitiveTagKeys": "transitive_tag_keys",
    "transportProtocol": "transport_protocol",
    "treatMissingData": "treat_missing_data",
    "triggerConfigurations": "trigger_configurations",
    "triggerTypes": "trigger_types",
    "trustedSigners": "trusted_signers",
    "tunnel1Address": "tunnel1_address",
    "tunnel1BgpAsn": "tunnel1_bgp_asn",
    "tunnel1BgpHoldtime": "tunnel1_bgp_holdtime",
    "tunnel1CgwInsideAddress": "tunnel1_cgw_inside_address",
    "tunnel1InsideCidr": "tunnel1_inside_cidr",
    "tunnel1PresharedKey": "tunnel1_preshared_key",
    "tunnel1VgwInsideAddress": "tunnel1_vgw_inside_address",
    "tunnel2Address": "tunnel2_address",
    "tunnel2BgpAsn": "tunnel2_bgp_asn",
    "tunnel2BgpHoldtime": "tunnel2_bgp_holdtime",
    "tunnel2CgwInsideAddress": "tunnel2_cgw_inside_address",
    "tunnel2InsideCidr": "tunnel2_inside_cidr",
    "tunnel2PresharedKey": "tunnel2_preshared_key",
    "tunnel2VgwInsideAddress": "tunnel2_vgw_inside_address",
    "uniqueId": "unique_id",
    "updateDefaultVersion": "update_default_version",
    "urlPath": "url_path",
    "usagePlanId": "usage_plan_id",
    "usageReportS3Bucket": "usage_report_s3_bucket",
    "useCustomCookbooks": "use_custom_cookbooks",
    "useEbsOptimizedInstances": "use_ebs_optimized_instances",
    "useOpsworksSecurityGroups": "use_opsworks_security_groups",
    "userArn": "user_arn",
    "userData": "user_data",
    "userDataBase64": "user_data_base64",
    "userName": "user_name",
    "userPoolAddOns": "user_pool_add_ons",
    "userPoolConfig": "user_pool_config",
    "userPoolId": "user_pool_id",
    "userRole": "user_role",
    "userVolumeEncryptionEnabled": "user_volume_encryption_enabled",
    "usernameAttributes": "username_attributes",
    "usernameConfiguration": "username_configuration",
    "validFrom": "valid_from",
    "validTo": "valid_to",
    "validUntil": "valid_until",
    "validUserLists": "valid_user_lists",
    "validateRequestBody": "validate_request_body",
    "validateRequestParameters": "validate_request_parameters",
    "validationEmails": "validation_emails",
    "validationMethod": "validation_method",
    "validationRecordFqdns": "validation_record_fqdns",
    "vaultName": "vault_name",
    "verificationMessageTemplate": "verification_message_template",
    "verificationToken": "verification_token",
    "versionId": "version_id",
    "versionStages": "version_stages",
    "vgwTelemetries": "vgw_telemetries",
    "videoCodecOptions": "video_codec_options",
    "videoWatermarks": "video_watermarks",
    "viewExpandedText": "view_expanded_text",
    "viewOriginalText": "view_original_text",
    "viewerCertificate": "viewer_certificate",
    "virtualInterfaceId": "virtual_interface_id",
    "virtualNetworkId": "virtual_network_id",
    "virtualRouterName": "virtual_router_name",
    "virtualizationType": "virtualization_type",
    "visibilityConfig": "visibility_config",
    "visibilityTimeoutSeconds": "visibility_timeout_seconds",
    "visibleToAllUsers": "visible_to_all_users",
    "volumeArn": "volume_arn",
    "volumeEncryptionKey": "volume_encryption_key",
    "volumeId": "volume_id",
    "volumeSize": "volume_size",
    "volumeSizeInBytes": "volume_size_in_bytes",
    "volumeTags": "volume_tags",
    "vpcClassicLinkId": "vpc_classic_link_id",
    "vpcClassicLinkSecurityGroups": "vpc_classic_link_security_groups",
    "vpcConfig": "vpc_config",
    "vpcConfiguration": "vpc_configuration",
    "vpcEndpointId": "vpc_endpoint_id",
    "vpcEndpointServiceId": "vpc_endpoint_service_id",
    "vpcEndpointType": "vpc_endpoint_type",
    "vpcId": "vpc_id",
    "vpcOptions": "vpc_options",
    "vpcOwnerId": "vpc_owner_id",
    "vpcPeeringConnectionId": "vpc_peering_connection_id",
    "vpcRegion": "vpc_region",
    "vpcSecurityGroupIds": "vpc_security_group_ids",
    "vpcSettings": "vpc_settings",
    "vpcZoneIdentifiers": "vpc_zone_identifiers",
    "vpnConnectionId": "vpn_connection_id",
    "vpnEcmpSupport": "vpn_ecmp_support",
    "vpnGatewayId": "vpn_gateway_id",
    "waitForCapacityTimeout": "wait_for_capacity_timeout",
    "waitForDeployment": "wait_for_deployment",
    "waitForElbCapacity": "wait_for_elb_capacity",
    "waitForFulfillment": "wait_for_fulfillment",
    "waitForReadyTimeout": "wait_for_ready_timeout",
    "waitForSteadyState": "wait_for_steady_state",
    "webAclArn": "web_acl_arn",
    "webAclId": "web_acl_id",
    "websiteCaId": "website_ca_id",
    "websiteDomain": "website_domain",
    "websiteEndpoint": "website_endpoint",
    "websiteRedirect": "website_redirect",
    "weeklyMaintenanceStartTime": "weekly_maintenance_start_time",
    "weightedRoutingPolicies": "weighted_routing_policies",
    "windowId": "window_id",
    "workerType": "worker_type",
    "workflowExecutionRetentionPeriodInDays": "workflow_execution_retention_period_in_days",
    "workflowName": "workflow_name",
    "workmailActions": "workmail_actions",
    "workspaceProperties": "workspace_properties",
    "workspaceSecurityGroupId": "workspace_security_group_id",
    "writeAttributes": "write_attributes",
    "writeCapacity": "write_capacity",
    "xmlClassifier": "xml_classifier",
    "xrayEnabled": "xray_enabled",
    "xrayTracingEnabled": "xray_tracing_enabled",
    "xssMatchTuples": "xss_match_tuples",
    "zoneId": "zone_id",
    "zookeeperConnectString": "zookeeper_connect_string",
}
